import pandas as pd
import numpy as np

import subprocess
import os
import shutil
import sys


class DatabaseData:

    def __init__(self):

        self.database_seq_name = "sequence"
        self.database_value_name = "Value_identifier"
        self.database_text_name = "Text_identifier"
        self.database_seq = ['CAPQQTPGSIKHGGF', 'CTGGKQHQPGPSIAF', 'CQIGHPTPSQKAGGF', 'CPQPAHGTIGSQKGF', 'CGIGQKQPPHSGTAF', 'CAIHTPPGGKGSQQF', 'CQSGTQAIHPPKGGF', 'CGGQSQAPTGIKHPF', 'CTPGQASGIQPHKGF', 'CQGGIAHTQPSGPKF', 'CGAIPGHQPTQSKGF', 'CGKPAGIPQGTHSQF', 'CSPGQIHGQAGPTKF', 'CPQSQIAGTPKGGHF', 'CQQGAHIGGPPTKSF', 'CQTPGQAIKSHGPGF', 'CPGIGQAHTGQPSKF', 'CGHGSPGPAIQQTKF', 'CAHQPSGKQPIGGTF', 'CPIQGHPASQGGKTF', 'CAGTHQIGPPSKQGF', 'CAGPQSGGIKQTHPF', 'CKPAHTIPGQQGSGF', 'CTQQHGIPGSPGAKF', 'CHQGQAGPSGTPKIF', 'CPGIQHSGKQPGTAF', 'CQAQTKPSHPGGIGF', 'CTQIQPGGPKSGHAF', 'CPAIQSTKGHGQPGF', 'CPGAGQQKHTSPGIF', 'CITHPQGKQGAPSGF', 'CGGPQAIHGQTPSKF', 'CTAKPIQGGHQPSGF', 'CTAIHQGSQPPKGGF', 'CGPGIQKQSGTHPAF', 'CSGHGAIQGPKQTPF', 'CGPPGQAHSGTQIKF', 'CITGASGHQGPPQKF', 'CPIGQHGGKQASTPF', 'CGTIGHKQQPPGASF', 'CGSIHGPPAKGTQQF', 'CIAGSTGHPGPQKQF', 'CGHSAIPTQQGGPKF', 'CTIKHQGPPQGGASF', 'CQPHGAGIQSPKGTF', 'CSPQHAQGIGTPGKF', 'CSGQTGGPIKPHAQF', 'CGGHKGSPITQPQAF', 'CPQQAKGGTHGPSIF', 'CKTGHSIGPQAPGQF', 'CIGATQGGHPSQKPF', 'CSQAHKGPQGTPIGF', 'CPQGGKAGITPQHSF', 'CHKPISAGQPGQGTF', 'CTIPAQGSHQPKGGF', 'CGSGPATQKQHGIPF', 'CKQTQGGGISAPPHF', 'CQKGPHTPSGIGQAF', 'CSTHQIPQKGPGAGF', 'CKHIASPQQGGPTGF', 'CAHGSTQGPIPKGQF', 'CQGTGAPPHSGQIKF', 'CHKPQPGATSGQIGF', 'CGPKITGHQQGSPAF', 'CKQPIHGGAGSPQTF', 'CKQGITHGGQSPPAF', 'CAQQGKPSGTGPHIF', 'CQGKHTPAPGISQGF', 'CGSAPGTGKQPQIHF', 'CQQHTPGGGKAPISF', 'CIGPPGQGQAKTSHF', 'CKISGHTGGAPQPQF', 'CGPPAQGHITGSKQF', 'CQPQHPKTGGGIASF', 'CSKHPTGQQGGIPAF', 'CHIGPGPQATKQSGF', 'CIKGGSPQTQGHAPF', 'CPGKITAQGQPGSHF', 'CGQPQTKPSIGHAGF', 'CPHSIQPTGAGGKQF', 'CKGPPGGSIATQHQF', 'CKSPAQGQITPGGHF', 'CSAGGIKQGPHTQPF', 'CIQHGGPTQKPSAGF', 'CGQKGATGISPHQPF', 'CAQPGPKHTISGGQF', 'CGPQATHSKGQPIGF', 'CQPKGQPISTGGAHF', 'CPGTPSKIGQQAGHF', 'CGGQKSQTIPGPAHF', 'CPKIGAQGHGQTPSF', 'CAPPSHQKTGIQGGF', 'CPQPGKISQTGAGHF', 'CGSPPHGGQITKQAF', 'CTQGKHPASPGQGIF', 'CQITQPKGHGASPGF', 'CSPGQGHAGPKTIQF', 'CIGAQPGPGSTQKHF', 'CGHSAGQGKQPPTIF', 'CAIQQPTGKSHGPGF', 'CHTGAPKQQIPGSGF', 'CQAIPSGTHQGKGPF', 'CAPQQTPGSIKHGGF', 'CAGQGTHPPIKGQSF', 'CGHAQPGPKTGIQSF', 'CIGPGKTPGHAQQSF', 'CPQAKQHTIGGPSGF', 'CQHAKQPGIGGPSTF', 'CPGGKQATGQSHIPF', 'CGKPQSGIPTGAQHF', 'CTAGPKIPQHGQSGF', 'CGTKAPHQIQGSGPF', 'CKTAGIPGQPSHGQF', 'CGKSPHATPQIGGQF', 'CGGHGKQAPSQITPF', 'CIGPPQSTQHAGKGF', 'CHTGGAKPPQSIQGF', 'CKPGTHSGGIPQQAF', 'CQGSPIGQGATPKHF', 'CKPQGGIGASQTHPF', 'CPTGPGGQAISQKHF', 'CKTSQHQGGGPPIAF', 'CSQKPGTIHQGAGPF', 'CAQHIGSGTKGQPPF', 'CQPPTGHSGIQGAKF', 'CAPIGSTQPHGGKQF', 'CSKGTHGIGQPAPQF', 'CPQGHPKASIGQGTF', 'CPQISPKQGGHTGAF', 'CGKSGTQQAGPIPHF', 'CQKIHGAPSPGTGQF', 'CKPGTPAHGIGQSQF', 'CSGKGTQGAPQHPIF', 'CGTPGHPSQAIKGQF', 'CSPKGGHPAGIQTQF', 'CPQGSKPGGATHQIF', 'CPTIKGQAHSPQGGF', 'CAGHPPQGTKQGISF', 'CTGPIGGHAQPSQKF', 'CPGGSAQIPHQGKTF', 'CPSGHQGATGPKQIF', 'CGIKQTSGAHGPPQF', 'CSPGHQPAGTGIQKF', 'CGIQGSHGPQAKPTF', 'CQKPPGTGGHQISAF', 'CPPAGSQHTKQGGIF', 'CKQAGSGHTPGPQIF', 'CKGTIHQQGPPAGSF', 'CKTIGPQGSGQAHPF', 'CKISPHGAQGGTPQF', 'CSQGPITHQGAGKPF', 'CKTHSIQGGGPPAQF', 'CIQPQGPTGHSAKGF', 'CAGQHGQSKGPIPTF', 'CSAQGGTQGHPKPIF', 'CQGSTHPAIQGPKGF', 'CGQKIHPPQGAGSTF', 'CIGPHTAGSPQQKGF', 'CIGQGPPATSQKHGF', 'CQAGPSIKTQPGHGF', 'CAIGTPQHGSPQKGF', 'CTGSPGPHAQKQIGF', 'CAHPGTPIQSKQGGF', 'CGPASTHIQQPGGKF', 'CGTHPPGAGSIQKQF', 'CAQHKIGSQTPPGGF', 'CGPHGPQQAGTKSIF', 'CAPQQISPHGTKGGF', 'CQQIHTPGGAPGSKF', 'CSGQAPHPGKGQTIF', 'CAKHPGSIQPGQTGF', 'CPGQKIHGQGATSPF', 'CGHIAPQSTGGPQKF', 'CPGQHGISGQAKPTF', 'CPSTGAHPIQGQGKF', 'CHKTGGPPSQAQGIF', 'CKSIPAPHGGGQTQF', 'CQPGIHPASQGTGKF', 'CQAHIQGGGPSPTKF', 'CTPSPKQGIHQGGAF', 'CPQPGGKIAQGHSTF', 'CPGGTHKGAQPSIQF', 'CPQTSGAIHQKGPGF', 'CPQPSTQKGAHIGGF', 'CGITPKGPHAQQSGF', 'CQHIGQAGGKSPPTF', 'CTGPQQKHGAGSPIF', 'CQHQTAPKIPSGGGF', 'CQIQGHPGSGKATPF', 'CGGSTPAKIQQPHGF', 'CQGTGQKIHGPASPF', 'CPPIGAHKGQGTSQF', 'CQPQGTAPSGGKIHF', 'CGHTKSQPAGIPGQF', 'CQPPQGGSGHKIATF', 'CQAQSGKGPTPGIHF', 'CGPGQKSIQGHATPF', 'CTPHQIQGPKSAGGF', 'CPHSTIAGGQGPQKF', 'CKSQGPQGIPHATGF', 'CSGKQPPGQHTGAIF', 'CPGSKQHGPQAIGTF', 'CPHQKSGTGGIAPQF', 'CGAQPPSQGTHIKGF', 'CSHTGPQGGKQAIPF', 'CKSGQGPGIHTPAQF', 'CPIQHAGKQGTGSPF', 'CIPSPGTQGHAKQGF', 'CPQKASIGTHPQGGF', 'CKGQQGIHPPGTASF', 'CHIGKTSAQPGGQPF', 'CPGGQQSTPGAKHIF', 'CPGSHQPAGQTKIGF', 'CGTQPQGISPGHAKF', 'CTGGPQPIQAHGKSF', 'CIGATPKQPHSQGGF', 'CHQSIKAPGQGPTGF', 'CQATSQGPGKIPHGF', 'CAGTPKQGHSGIPQF', 'CGGPHAIQGPSQKTF', 'CGATKIHPQQSGGPF', 'CPGQPSHTKQGGIAF', 'CQGAIHSKGQPTGPF', 'CTPQGSGGIAHKPQF', 'CTPGHKGGAQSIQPF', 'CSTQPPGGHIQKGAF', 'CHPKGQAPTQIGSGF', 'CPTGGAQGKHIPQSF', 'CGPQIKHGAQTGSPF', 'CGITAKSPQGHQPGF', 'CTKSGQAQHPGPGIF', 'CQSPHGKPGTQAIGF', 'CKPGSQGHGIPQATF', 'CGIKQTSGAHGPPQF', 'CPPGGSTKQHQIAGF', 'CQPQKGPASTIGHGF', 'CAQSPQHKGGTIGPF', 'CGGSGPPTQIAQKHF', 'CHSPQAKTGIGGQPF', 'CGSGPQPTHAIKQGF', 'CAQPGKGHITQSGPF', 'CPAGGSHIPKQGTQF', 'CPITKSQGGGHQAPF', 'CIHPPGGSQTKGQAF', 'CHQTPPGGGQSKIAF', 'CSIGQGHAKQGPPTF', 'CGPKHGATPIQSQGF', 'CAQQHKGPSGGPTIF', 'CGGGAPQKPISTQHF', 'CGQGGQKIAHSPPTF', 'CGAQSIPGTQPGKHF', 'CPASGKQPIGHGQTF', 'CHPIQPKGTAGQGSF', 'CTHQGSAIKPPGGQF', 'CPKAQQGTGPISHGF', 'CPIGATGGPHKQQSF', 'CGIGHAPKQGPSTQF', 'CQGSGGPAIKTQHPF', 'CPSAPTIGQHKQGGF', 'CGISGTKQAGPHQPF', 'CAQGTGHGKSPQPIF', 'CGSPGKIQAPTQHGF', 'CSGPAHIQGPTKQGF', 'CHGQAKQPSGTPGIF', 'CGQPHSTAKGIPQGF', 'CIPPQTSGQGGKHAF', 'CGTPQIHPQSKGAGF', 'CGQQGKPAPGITHSF', 'CAHGGKTGPQIPSQF', 'CPTAGAQGKHIPQSF', 'CPPQGKTHGQAIGSF', 'CTQQHSGIPPKAGGF', 'CPGTHASKGIQQPGF', 'CQGGGKTIAHSPPQF', 'CHQATPQSGKPGIGF', 'CSTIAKPGPHGGQQF', 'CIGHTPPQGGQKASF', 'CQKTPHQGPSAGGIF', 'CGQTGPPKQSIHAGF', 'CQGTSIPAGKQGPHF', 'CQGPHTPKAGSGIQF', 'CKQGAPGHQTGIPSF', 'CPQHGGISTPKQGAF', 'CKQPHQTPIGAGSGF', 'CIASGGTPQQKPHGF', 'CQTPPGKGQHAIGSF', 'CQSHGPGQPGIAKTF', 'CSGKIQPQPTHAGGF', 'CGSGIAPTQQGPHKF', 'CAGKQQSPGGIHTPF', 'CIQGPHGSQGAKTPF', 'CAQTKQGPGSIGPHF', 'CPGPHGQIKGQASTF', 'CPPQAHQGSIGKGTF', 'CSAPQGIQTGKPHGF', 'CQAHSGITGQPGPKF', 'CGGKHTSPAPQQGIF', 'CHSQTAKPIGGGQPF', 'CHGGPSAQIPQTGKF', 'CPQGPGHTIQAGKSF', 'CTPHGIGQSPGQKAF', 'CKTGPQSAHPQIGGF', 'CGQQKPSTHAGPGIF', 'CSGHKTGPQGIQPAF', 'CPQPKAGSIGHQTGF', 'CPTAGHQISPGKGQF', 'CAKPIQGTPGGQSHF', 'CIGSQPGPHKTQGAF', 'CPAGPKQITQSGGHF', 'CKIPHQAGSPQGTGF', 'CGQPGTQIGSAKPHF', 'CGHGIPPGQKQATSF', 'CGGIGHTSQPPKAQF', 'CGASHPPKGQQTIGF', 'CPGGKGSPIHATQQF', 'CPGTSQIKGAPHGQF', 'CQPHPGKGSIATGQF', 'CQPGKQGGASIPTHF', 'CGSAKTQIGPHPGQF', 'CGIKTGGPAHQQSPF', 'CQQATGSHIGGPPKF', 'CIHAGPQKGTPSQGF', 'CSPAIPHQTGGGKQF', 'CPHQAGKQTGIGSPF', 'CKQQTASGIPGHGPF', 'CSIQPAPTKHGQGGF', 'CQQKGIPHTPSGGAF', 'CSPIQTGGKAQPGHF', 'CPKTGQQSAHGGPIF', 'CAGQPPQGHKGSITF', 'CGKISGPQTAGHQPF', 'CGTGAQIPHKQGSPF', 'CQTHASQGKPGPGIF', 'CGGTPQSQHAIPKGF', 'CQQHASTKGPGGIPF', 'CPHGPKQAQSGIGTF', 'CPGQPQKGTHASGIF', 'CPGPAQGTGSQIKHF', 'CGKSQGPQGPAHITF', 'CSPHGQGKIGQAPTF', 'CKSQHQATIGPGGPF', 'CQAQPPGIHGTKGSF', 'CGGAGQHTPKQIPSF', 'CPHQGIAGTSGKPQF', 'CKQSPGIGAPGHTQF', 'CQPIGGSAPTHGQKF', 'CPAIGQKTGQPHGSF', 'CATGIHGQSQPKPGF', 'CAQQKGPGSPGIHTF', 'CQSGIHPGPAGTQKF', 'CTGQKAGSHQPPIGF', 'CGGQIAKTPQSGPHF', 'CPKGSQIHTGPQGAF', 'CPSGPQHGKTIAQGF', 'CQPPGGAGTQIHSKF', 'CTIGPAGHKPSQQGF', 'CIQHGGPKQTGASPF', 'CGSKHGITPGQAPQF', 'CTQQSHKGAIGPPGF', 'CHIPGSQPGQTGKAF', 'CKQASGGHPQTGIPF', 'CQSAQHGPIGTKGPF', 'CTGGPSIHPQAKQGF', 'CPQIAHSQTGPKGGF', 'CHGKQGITGQPPSAF', 'CGGSPHPQITGAQKF', 'CQQPGIPGKGASTHF', 'CSGIPAGQQKGPTHF', 'CGPGSHGQIATKQPF', 'CQATQSGGIHGPPKF', 'CGPGHGAQTKISQPF', 'CPGGSHPKQQAIGTF', 'CQGSPITGQAPGHKF', 'CQPAKTPGSGHQIGF', 'CQTGGSIAPQHGPKF', 'CGGHPPTQSIKQAGF', 'CKAQGPTQHGPIGSF', 'CQQKPSAIGHGGPTF', 'CPGKPQSTGQGIAHF', 'CQSQPPGTHGAKIGF', 'CGSQPPITKAHPQGF', 'CPKISTHQQPGAGGF', 'CSGPGGPQKHAITQF', 'CSTGPPAIQGQHGKF', 'CSHKGPTAGIQQPGF', 'CGHTPSQAIGGQPKF', 'CGSGQPGAITPKHQF', 'CGKSQGPQGPAHITF', 'CITGSHGPQQGKAPF', 'CKHGAQQIPGSPTGF', 'CGSKGAQPTHIGQPF', 'CTQHKPQGSIGAGPF', 'CGSPTQQPAGHGIKF', 'CIGPTSKPQQHGAGF', 'CQKGGHSQAPGTPIF', 'CHIPGQGGSPTKAQF', 'CSGTPPIQQHAGGKF', 'CPQQGTHSGKIAGPF', 'CGPAGGQKISTQHPF', 'CGPHSPQAGQTGIKF', 'CPGGSGQTIHKQAPF', 'CHQPGSQGPKAIGTF', 'CKSTGAQHGPPIGQF', 'CGSHTPQGAKIQGPF', 'CHPKIGPQQGGTSAF', 'CHKQPGGPTQAIGSF', 'CQITPSGHGGPQKAF', 'CGPAGKSIGPHTQQF', 'CSTQIKQGGGAPHPF', 'CQPATIGGSQGHKPF', 'CISGPQQKGTAHPGF', 'CPSTQGKPAQGHGIF', 'CGQAISGQHPKGTPF', 'CKASGPITPGHGQQF', 'CISKQPGTGAQHGPF', 'CITPGGKSAHPQQGF', 'CKGQGSPHAQPTIGF', 'CSQGQGPIKHGPATF', 'CQGGIAHPTQSKGPF', 'CGPQQSTPIHAGKGF', 'CGPGTKIQPAGQSHF', 'CSQAGQPIGKPHGTF', 'CPPATGQHQSIGKGF', 'CTQGAKPPHQSIGGF', 'CTGQAHQPSPGIKGF', 'CKSGQAHIGGQPTPF', 'CAPPKTQQSGGHIGF', 'CGAPIQSQPGKGHTF', 'CPKPHISGQGQTAGF', 'CGAQQTIGKPHPGSF', 'CHSGPQTAKGGPIQF', 'CAQQPGSKPTGGIHF', 'CSGITPGQGHPKAQF', 'CSGKQPGTPHQGAIF', 'CGQHGKQTAPISGPF', 'CQIPAHQGPSGTKGF', 'CPKTGQQSAHGGPIF', 'CGQTKPIGPQHSGAF', 'CGQPGTQIGSAKPHF', 'CHGKGIAPPQGQTSF', 'CQQATKGHGPSGPIF', 'CHPGGTQPSQGAIKF', 'CAQPKHTQGGSIGPF', 'CQPGASKPGGTQIHF', 'CGKSAPTQQHPGIGF', 'CQAGHPTGPQSGKIF', 'CGGGPQSHQATPKIF', 'CGSIGQPGQTHKPAF', 'CQTIPAQGKPHGSGF', 'CPKGHQGGIQATSPF', 'CPPGGSQGHKITAQF', 'CHQPGTPGKSGAQIF', 'CIPGQSPQGKAHTGF', 'CSGGGIPKHTQQPAF', 'CAQGPHGPTGQSIKF', 'CQGPTSGQHAKPIGF', 'CHAPQGSTIKPGQGF', 'CHQKPQSPGTGGIAF', 'CPIHQKGPQASGGTF', 'CKSHQAGPQTGIPGF', 'CGPAPQKSQHTGGIF', 'CQKSITGQGHGAPPF', 'CSTKIQGQHPPGGAF', 'CGISGGQAQKPHTPF', 'CGPQHTKSIQAGGPF', 'CGQSPAGGKHQTPIF', 'CIGQKSAGQGPPHTF', 'CGSTKAPGGQIPQHF', 'CGPISPGKTQAGQHF', 'CGQTKGISHQPPAGF', 'CAPKGSIQQHGTGPF', 'CHPKSQTQPGGAIGF', 'CHGKGITPQAGSPQF', 'CQHGAKQTPPSGGIF', 'CSAPGPGHTKQGQIF', 'CIPGKGSTQGPAQHF', 'CQQSIPGATGKPHGF', 'CQIPSTGHPKGAGQF', 'CQPSKHGQIAPGGTF', 'CQPAHGSGPTIKQGF', 'CGQAPITGHGPKQSF', 'CPQGGHIAQKGPTSF', 'CPQPGGKIAQGHSTF', 'CSTHQPQKGGAIPGF', 'CITPAKGQGSPHQGF', 'CGIAPHPGQKQSTGF', 'CTQHGPGSKIAGQPF', 'CGPKHQAGTPSIGQF', 'CAPQKSGQGHGTPIF', 'CHAIQGTGKQSPGPF', 'CIQPTGASPGKGHQF', 'CIQPPAHQGSGGKTF', 'CGPGQTAHIKPSGQF', 'CQIKPGSATPHGGQF', 'CQGHKIAGPPGQSTF', 'CSTGHPKPAQIQGGF', 'CQPQHPKTGGGIASF', 'CQGKTGHQPSIAPGF', 'CPGSKIPHATGQQGF', 'CPHGPGQIATQKGSF', 'CHGITGKGAPPQSQF', 'CQAPHKPITGQGSGF', 'CKQGGHTQPGSPAIF', 'CPAHGTQGIPSKQGF', 'CGSPHPTGQQIKAGF', 'CITQGGGPSHKPAQF', 'CQIPTPAKQGSHGGF', 'CTPGQQSAHPKIGGF', 'CQQGIKHGTGASPPF', 'CHQAGIQTGSPGPKF', 'CPQQKGGGHTASIPF', 'CGIHTPQASPQKGGF', 'CHQGPIGASKTGPQF', 'CKQGPSGPTKAQGIF', 'CPTGQPQGSAKHGIF', 'CQGGGPQTAPISKHF', 'CQHIKGQPGTPSGAF', 'CAQHGPKIGQGTPSF', 'CQPGKGPSQGIATHF', 'CQGHGGSTAKPQPIF', 'CGIHSGQKAQPTPGF', 'CKAGTGGPSIQHQPF', 'CSGKPPQGTGAIHQF', 'CGAPPSQGIQTGKHF', 'CKGSPPHQQGGITAF', 'CGGQKISPPTQGHAF', 'CQHIATPGGSPKGQF', 'CQTIQGGASGPHPKF', 'CGPQGSIGKQHTAPF', 'CGPHQPTQGGAIKSF', 'CATKGIQPPGSGHQF', 'CPHGIQGKSPGQATF', 'CHQPAPIGTKQGSGF', 'CPAGHPSQIKGGQTF', 'CAKGGHTQGPPQISF', 'CAQIHPKPQSGTGGF', 'CPISQQKGPGAGHTF', 'CIQKGPGTQHSPAGF', 'CQPSGGTAIPKQGHF', 'CHGKTGGQIPSQAPF', 'CSPQAGKIGPGTQHF', 'CGGPTSQHKPAQGIF', 'CHGPAGPKQITSQGF', 'CQPQKGPASTIGHGF', 'CPAQHGPGQGSIKTF', 'CPHSPQGQIKAGGTF', 'CPPHKIGGGAQTQSF', 'CIQPTSGGKGHAQPF', 'CQKISHQPAGPTGGF', 'CPGGQQPSGIKHATF', 'CGQQAITSPGPKHGF', 'CQQGPSIHPGGTAKF', 'CGKAIGQSGHPQPTF', 'CQSIHQGTPGKAGPF', 'CGPQGHIQSGPATKF', 'CKPASGGQPGTQHIF', 'CATIHSKGQPQGGPF', 'CGTGQPQKIHPASGF', 'CIGHPSGPGQKTAQF', 'CQGIPPSGKAQHGTF', 'CIKGPQQGSAGPHTF', 'CQGQAPSGIKPHTGF', 'CPPSQGKGTHQIAGF', 'CSQIQAGGGKPHTPF', 'CSGQGPGPKAHIQTF', 'CASIGPPQQHGGKTF', 'CQPKHGATGIGQPSF', 'CSIQQGAGKPGHPTF', 'CGAPQHGGQTKSPIF', 'CAHSQGTGKPQIPGF', 'CTQKIGHQPAPGSGF', 'CAHQGPPGTGQKISF', 'CTAQSPPQHIGGKGF', 'CKHSGGPIAQQPGTF', 'CQGPGGIAPQTKHSF', 'CKQTHGSGPPIQGAF', 'CGPGPQAKQGSIHTF', 'CPPHGQTGQISAKGF', 'CTPQPGIGGSKHAQF', 'CASKPQHGPGQTGIF', 'CKASIPQGTHGGQPF', 'CPSKTHGGPGAQQIF', 'CHASPTKIQPQGGGF', 'CHPQTPSGIGAGKQF', 'CTPGGGKIHSPQAQF', 'CQIGGTAKPQPSGHF', 'CQGGTKQSAPHPGIF', 'CTQGGSGQPHIKPAF', 'CGHIQTQPASPKGGF', 'CSPPGKGQIQAHTGF', 'CGISPGTAHQPKQGF', 'CGHKQGAGPIQPTSF', 'CPHGTSKPGQIQAGF', 'CIHSQGAGPQTPGKF', 'CHPQIKASGGGTPQF', 'CKGHQPPTQAGGISF', 'CSPGGKQHTIGAQPF', 'CAGGQTGPSPHQIKF', 'CPGISPQGAKTQHGF', 'CGQPAPHKTGIGSQF', 'CTQSKIGQAGHPGPF', 'CPSGPHGIQQKTAGF', 'CAPQQSPTIHGKGGF', 'CTSPGAQGHIQPKGF', 'CTGQGHQPGPISKAF', 'CGIPTSQPAHGGKQF', 'CPQGHAKQGPITGSF', 'CQQTSIPHGGGKPAF', 'CSQGGKITPAGHQPF', 'CSAPGHGKQQIGTPF', 'CGPPSTGIHGKAQQF', 'CHGSQTPGGPIQKAF', 'CGQHSGPGIQAKPTF', 'CGHTGQGQPPAISKF', 'CTGGSPKHQGPIAQF', 'CQHAIPPTQGGSKGF', 'CHQSAPGQGKITPGF', 'CGIKSTQPPHGGAQF', 'CTQPKPGGQGIHASF', 'CAGQPSGTPIQKGHF', 'CQHGPQTSPKGGAIF', 'CIPKPGSHAQGTQGF', 'CAQTPGHGQSIPGKF', 'CSGGQPGPAKTHIQF', 'CGSHGPAIKQQTPGF', 'CHPGIKGATSGPQQF', 'CQPISQGTKHGAGPF', 'CQTHGPAIKQGPGSF', 'CSTGKPGIAQQPHGF', 'CTHPPGGASGQKIQF', 'CGGGASQPPTQHKIF', 'CGQGPISPGTAKQHF', 'CSHGGATGIPQPQKF', 'CTQHPGGAKPQSGIF', 'CKQGPSGPTHAQGIF', 'CQIGGPSQKPAHGTF', 'CGTHPGKPQGQSAIF', 'CHGGKIQPPGTSAQF', 'CTQSGPKGHQAPGIF', 'CKGQTHGGPPASIQF', 'CTKGQHIQSAGGPPF', 'CHKPGGQSQPITAGF', 'CIQTQGAHPSGPGKF', 'CSGPAHGKQTIGPQF', 'CQSKPGAGGHPTQIF', 'CSPKGGTAPQQGIHF', 'CHGQKAGPQIGSPTF', 'CHIGPQQGPKASGTF', 'CATGIHGQSQPKPGF', 'CHKGIPQQGGPTASF', 'CSGQGPAIQPHGTKF', 'CHPGQAKPTGGIQSF', 'CQQTIGKGHPAPSGF', 'CTIKPQAGQHGPSGF', 'CQGAIQSPGTKGHPF', 'CIHQSPGGQAGTKPF', 'CHGIATQSKPGPQGF', 'CPIQPTQGASGGKHF', 'CTHPGKGIPQASGQF', 'CQQGPGISAKPHGTF', 'CHGQGKQTIAPPGSF', 'CQPGAQKIGPSTHGF', 'CASHPKGPQQGIGTF', 'CGSPQQPGAHIGTKF', 'CITKAQGPSGQGPHF', 'CPGIQGKQPTSHGAF', 'CGGSPGQAITQKPHF', 'CGQPQPTAHGIGSKF', 'CQGAGPPKQHIGTSF', 'CKIGQSGGPTPQHAF', 'CSQPGQIATPHGKGF', 'CGPTPQQSKHIGGAF', 'CTGQGIKSPQGAHPF', 'CKIPGQPSQHGGATF', 'CSKIGPGPQATGHQF', 'CAHTGQPQKIPSGGF', 'CQPKTGPQGGHASIF', 'CKQAIGPQHTGSGPF', 'CQPTAHIGGGPSQKF', 'CTGQKPHPAGSQIGF', 'CAQGQPKPGHTGISF', 'CKQTGHISAPPGGQF', 'CGGISQGHPTPKAQF', 'CKHQGGPSPTAGQIF', 'CIHQGKTSPPQAGGF', 'CIQKQTSGPHGGPAF', 'CGTKQIHGSPPGAQF', 'CTQAGGSQHPIKPGF', 'CSTHGGQQKPPGIAF', 'CGPTGKISAGPQQHF', 'CQTQPGKGIHSGAPF', 'CTSIHGQQGKPAGPF', 'CGSQPPITKAHGQGF', 'CSPIGQTHGKGQPAF', 'CQGPHSGGTQKAPIF', 'CGQHQTGGSIPPAKF', 'CGPPHKITQGAGQSF', 'CPQPHSIKGGGQTAF', 'CQGHGTPQIGSKAPF', 'CPGSGIHQKQTPGAF', 'CPGGHSIPTKQGQAF', 'CTGIASGKQGPQHPF', 'CSPGHQGAKPITQGF', 'CQIGPGKPSHQAGTF', 'CAPGQQPKTSIGGHF', 'CPQGSQPAKIGHGTF', 'CTQIQPKPHGSGAGF', 'CAGKTQGQHPSIPGF', 'CSQPGAHGGTKQPIF', 'CGHPGATSIGKQQPF', 'CPPGGSATGKQQIHF', 'CTPSGIQAHPQGGKF', 'CQQPSGKAITPGGHF', 'CGPPGGHSIQQTKAF', 'CPSKPQGHTAGQGIF', 'CKIQPQAGPSTGGHF', 'CGPKTQAPIQGSHGF', 'CGPQPKGIASGTHQF', 'CHGGPQKPGASTQIF', 'CGQPGKPTGSHQAIF', 'CQQKIATGGSPPHGF', 'CAQIHQTPPGSKGGF', 'CQKTSGGQAHPGIPF', 'CGTKHSIPGQGQAPF', 'CTQGGPSGKQAPHIF', 'CKSPPGIGQQAGHTF', 'CGKGPGHSATQPIQF', 'CAPKGGQTQGSPHIF', 'CGATGKHSPGPQQIF', 'CAGPPKGQGQIHTSF', 'CHQGPQIASGKPTGF', 'CAPGGIHGTKPQSQF', 'CQKGGIQPSPGHTAF', 'CPQGGPGHITKQASF', 'CTHGGPQISAPGQKF', 'CPIGSPGQTGKHAQF', 'CGAIPTGQKQHPGSF', 'CSKQHGIAPTQGPGF', 'CHPSGAQGTQGPKIF', 'CGGPQSHPKTGQAIF', 'CTHSPPGGGKAQQIF', 'CPHKAQPGISGTQGF', 'CIQPAGSTPHQKGGF', 'CAPSIPTGGQHQGKF', 'CSGIPKGAHPGTQQF', 'CPPKQQGAHSGTIGF', 'CTKGIHSQQGPGAPF', 'CIHQGAGPTSKPGQF', 'CTPGQPSQIGGHAKF', 'CPIQGHPASQGGKTF', 'CHQITGKGPSGAPQF', 'CKPPGQIGATQHSGF', 'CGQAKSPTGQHIPGF', 'CGSHAPPGQKQTGIF', 'CAGPQHITSKPGQGF', 'CPGPKGQSQGAHITF', 'CSGQPAGGTKIHQPF', 'CGKGPSTPQAQHGIF', 'CPQHGGISTPKQGAF', 'CKTQSAIHGPQGPGF', 'CGKGGPTQIPAQSHF', 'CQKGTGGIPHQPASF', 'CGPGHTPSGQKQIAF', 'CPQTQGGGSAIKHPF', 'CGKHQAPPTQGSGIF', 'CQHSGQIGKPAPGTF', 'CQITGASPQPGHGKF', 'CIHQATGPQKPGSGF', 'CKGTSGHIQPQPAGF', 'CIPAGQHKPTGGSQF', 'CAQTPSIHPGQKGGF', 'CKGGSHPQTIAQGPF', 'CGQPHAGSGQPKITF', 'CSAQQTPGGHKIPGF', 'CGQSTGIAHKPPGQF', 'CSGAGPIGPQHKQTF', 'CHQKTGASGPPGQIF', 'CPGAGTHQQSGPIKF', 'CHQIAQGKGPGSTPF', 'CTGSPGPHAQKQIGF', 'CPGAKQIGTPSHQGF', 'CQKQGTGPAIHPSGF', 'CPIGPQGHSKGQTAF', 'CAGKQTQSPPGHIGF', 'CPHQQGGIASTKGPF', 'CGKQQGPHIATGSPF', 'CQGKTQPAGSIGHPF', 'CTIQKPGASQHPGGF', 'CPSGIQGTPAHKGQF', 'CQGQITPGSPKGHAF', 'CQSHIPGGQPTGAKF', 'CGKPQGQPASTGHIF', 'CPQIKQGGAGPHSTF', 'CGQGQTKAHPSIPGF', 'CQGGPSGKQPAIHTF', 'CPSTAHGKQPGQIGF', 'CSGGKPIQQTGAHPF', 'CKGGQIQSPGPATHF', 'CQIGPKAHGGTQPSF', 'CHKTQPGQGGSPIAF', 'CAGHQGKPQTPIGSF', 'CSITPAKPGGQQHGF', 'CGHPGAQPTKGIQSF', 'CGQSIPAGPHGTKQF', 'CGSGQPKHIQTAPGF', 'CHPIQPKGTAGQGSF', 'CSGAPTHIKPGQQGF', 'CHGTPGPASQQGKIF', 'CTHAQGSPIQGPGKF', 'CTIKQGSAGPHPGQF', 'CHTKGSIQGPGAPQF', 'CAPKPGSGGTQIQHF', 'CGGTSAIQHKPGQPF', 'CKIGTQGAPHQGPSF', 'CGIQHPSQATKGGPF', 'CQAGGGTKQPHIPSF', 'CGQGPIPSGKQTAHF', 'CGKPATQQGIGSHPF', 'CSIGGPKGTHAQPQF', 'CGKQQPGAGSHPITF', 'CPSPQIGGKQGATHF', 'CQKQHTAPGPGSGIF', 'CTQGAGSPQIPKGHF', 'CTPQAPGKSQGIHGF', 'CAISHGPQQPGTGKF', 'CPQIKHSGGPAGTQF', 'CKGITSGPGHAQQPF', 'CGPKGTPHQQSGIAF', 'CHGGPGITQQAPKSF', 'CQHKGPPAIQGSTGF', 'CQSGTHPGAKPIQGF', 'CGIPSQPAGGKHQTF', 'CGPQPSTGIGQAHKF', 'CKAGGHTSPIQPQGF', 'CPAIHQQGKGGPTSF', 'CGQAPSHGQPGKITF', 'CTPGPQSIHGQAKGF', 'CGIGAQTSGKPPHQF', 'CSPGIQPQTGAGKHF', 'CAKGGPGQIHTQSPF', 'CAGKGSQPTHPIGQF', 'CGQKGPGQHPASITF', 'CKISGGTQHGAPPQF', 'CTPGPQASHIGQGKF', 'CGSTPQGPIQKGHAF', 'CTIQGAHQKPPGSGF', 'CGQQIPAHGSTGPKF', 'CPGQHTASGIKGQPF', 'CIHSGPQTQGGAPKF', 'CQPGGGQPHKSAITF', 'CIPKGAPHSQGQTGF', 'CSAPPQGGGTIHQKF', 'CAGHPGQSPIQTKGF', 'CASKPGHGPGTIQQF', 'CTQGGQSPIAGPHKF', 'CGQGSPGAIHKTQPF', 'CITHGAGPPSQGKQF', 'CTGPPSQQHGGKIAF', 'CSGPTIGQAHQGPKF', 'CQGQHGISPPTGAKF', 'CQTPGGPQKASGHIF', 'CKGQPSQTPAGHGIF', 'CPGISPQGAKTQHGF', 'CAGHQTGKISPQPGF', 'CTKGPGASPQHQIGF', 'CTGIQKPHASGQPGF', 'CQSHPGGAGIKPQTF', 'CQTQHGIPGSKPAGF', 'CQTPHGPISGAKQGF', 'CGSQAGPPKIHTQGF', 'CGKAQGQPGTHSPIF', 'CTAGQPKQSIPGHGF', 'CTQASHGPPQKGIGF', 'CSGQPIAPKQHGGTF', 'CGQQASIPPGGKHTF', 'CGHQTSQGIGKAPPF', 'CHIQKPGTQSPGAGF', 'CGSAGQGPPHTQIKF', 'CGKGQIQGATPSHPF', 'CPGGTIPAQSGQHKF', 'CTGPKAQHIPSQGGF', 'CKGAQSIGQPTGPHF', 'CGQPQGSGITHAKPF', 'CGSPQPIKTHGAGQF', 'CPKPGQGATHQSGIF', 'CIGQSAPTGGKQHPF', 'CGSTAPKGQIPGQHF', 'CIGQGGPQTAKHSPF', 'CSAPTIHQQGGPGKF', 'CPGAHGKIPQSQTGF', 'CQAPPHGGSKGTIQF', 'CQIKAQHGTSPPGGF', 'CPASGHIKPGGQQTF', 'CQQKPIGAHPGTGSF', 'CAITGGQPSQGHKPF', 'CPGIAKHQTQPGSGF', 'CTSKGAPQGQHGPIF', 'CQQGKSHATIGPPGF', 'CSKGPGQQHATIGPF', 'CPATGQGQSKHPIGF', 'CAGGTQSGPHKQIPF', 'CIAPTGGSPHKQQGF', 'CGGAQTQPIPGHSKF', 'CQGKGIPSPQAHGTF', 'CKQGPSGPTHAQGIF', 'CQPSGKGIPGHTAQF', 'CIHPPQSKGTAGQGF', 'CITQSPHQAPGGKGF', 'CHQGIKGPQPATSGF', 'CQQGIPGASKHGTPF', 'CGHPPGAQSKGITQF', 'CQSITGGQGHAPKPF', 'CHGPKQTQPGAIGSF', 'CQKTAPIPHGGGQSF', 'CGPAPTIQQSGHGKF', 'CAQTSGKHGIQPPGF', 'CKGTIQPPASGQHGF', 'CAGGHQPIKPTQSGF', 'CPGQHPITAQKGGSF', 'CIPSAQPQGHKGGTF', 'CGPKQGQSHATGPIF', 'CPQGKGGQSPHTIAF', 'CHPGKAQPGTSIQGF', 'CGQGSGQTPHIPAKF', 'CHSGQKPTPIQAGGF', 'CHQPGGKTIPSAQGF', 'CKQGPQSTGAPGIHF', 'CGAPQGGQKPTISHF', 'CQGPIQSHGKAGTPF', 'CSAPITGQGHKGPQF', 'CPTKQGSIQAHGGPF', 'CKGIPSTGGHQPAQF', 'CGQPKIPHGQGTASF', 'CATSGQQGIPPHGKF', 'CAHGKPGISPTQGQF', 'CKGQPSIGHPTGAQF', 'CAHGIPPGGSQTQKF', 'CPPGSHTQQIAKGGF', 'CPHSKATIGGQQGPF', 'CGPAIHQQKPTGSGF', 'CAKGQGPQPIHSGTF', 'CPQQITHGASGGPKF', 'CHITGGASQQPGPKF', 'CGGHIPKSPAQQTGF', 'CQSKGGGTIAPPHQF', 'CAIKQPHGGTGSQPF', 'CIQPHGKTGSQAGPF', 'CAGISGTGQPQKHPF', 'CGQGGSHKQPTIPAF', 'CKPTGPSGIHGQAQF', 'CPKQQSPIAGTGGHF', 'CQHGASKTGIPPQGF', 'CIGPKQQAGTGPSHF', 'CQSTGPGGPIHAKQF', 'CHTGGSPQIGKQAPF', 'CTAGIGGKPQSQPHF', 'CGTPHQSIQGAPKGF', 'CSHQTKGPAGGIPQF', 'CPGGQTPHQKGASIF', 'CKHIQGPGSQGPTAF', 'CIQKPSHTGPGQAGF', 'CAHGGPPGIQQSTKF', 'CKGPIGPAGQQTHSF', 'CPIGQHAGSPTKGQF', 'CTSPQPQGAHGGIKF', 'CPQPQSGGKAHGTIF', 'CTGHIGGPQQPSKAF', 'CIGPQAHQTGPKGSF', 'CTKQGGPIQHPSGAF', 'CAGQITGHQKPPGSF', 'CSPPQGTQGKAHGIF', 'CAQPGSQHTGIGPKF', 'CTPGSIPKAHGQQGF', 'CSPTQAPKGQIGGHF', 'CQPGIKTHGQGAPSF', 'CQPKTGGAPQSIHGF', 'CKGHPGPQTAGSQIF', 'CPSKAGPGQGTHIQF', 'CQHQITKGGSAGPPF', 'CHAGTGGQPQISKPF', 'CAPTGQHIGSKPGQF', 'CGGSKGQPHIQPATF', 'CGIKTGPQQPAHSGF', 'CTHAPIKQQPSGGGF', 'CQPGATSKGPGQHIF', 'CSGGITGKHQQPPAF', 'CSGAQGGHPKPTIQF', 'CAIHGGPTGQPKQSF', 'CAGHQKTSQGPIGPF', 'CPGGGKQTSPAIQHF', 'CGGKHTSPIPQAGQF', 'CSGAGPHIPQQKTGF', 'CPGTGIHPASGQQKF', 'CPSIQTGQGGPHAKF', 'CAQQSTKGPHGIGPF', 'CGPTQIKGQSPGAHF', 'CTGKAIHGSPQQGPF', 'CGSIHAPQKGGPTQF', 'CGPQGSAPTKHIGQF', 'CPGKQTIAHQSGGPF', 'CGGSPAGHKTIPQQF', 'CGHGAGPIQQKTPSF', 'CQGGPTQAIKSGPHF', 'CKHQTQIPGSGAGPF', 'CPGSGIQQGAKPHTF', 'CSTQPPIGGAGKHQF', 'CKASIPQGTHGGQPF', 'CQSGQTKIGHPGAPF', 'CPGIAQKPGHGSQTF', 'CKGAPGITSQPGQHF', 'CSPIGGGTQHKPAQF', 'CGQGHISGTAKQPPF', 'CPGHQGQGIAKTPSF', 'CKAPQQTGISHPGGF', 'CPGQQAITSGKPGHF', 'CPTQGGSGKIHQPAF', 'CPGQPSGTKAGHIQF', 'CGHGPQTGSQKAIPF', 'CQKTQPGISHAGGPF', 'CSQAQGGKPTGHPIF', 'CGQATQHKGGPSIPF', 'CGQGTGAQIHPKSPF', 'CGQGPSQHIPKTAGF', 'CQQHGGPKAIGPTSF', 'CQHGAIPTPQGSGKF', 'CPKTQHIGPAGSGQF', 'CTGQGAKPPISGHQF', 'CSGQPTAQPKGHGIF', 'CPGQSTAGHIQKPGF', 'CQHPQSGTGGAKPIF', 'CHIAKQPGGSPTQGF', 'CQHKGTSPIGAQGPF', 'CGGHAGPIQQSTKPF', 'CPSQTGKHGGQIAPF', 'CQKTPSHPGQGGAIF', 'CQAGPKGQGPSTHIF', 'CPIQGGKPHASTQGF', 'CIKPHQASGGGTPQF', 'CGKHSGQAPPGITQF', 'CIPGQHAGPKGQTSF', 'CQPTPGAQGSGKHIF', 'CGTGHQQPGSIKAPF', 'CGGIPHQQTSKPGAF', 'CGKHQAQPTQGSGIF', 'CGGIQQPKSPHAGTF', 'CGSQTPGQHKGPAIF', 'CKQSPAQPGGGHITF', 'CQSIGKPQAGGTPHF', 'CAPSKHTIQGPGQGF', 'CGHQPSKAGQPITGF', 'CSTQGGAKGPPQIHF', 'CPQTQSGPAIKGGHF', 'CSGKQAQGTIGPHPF', 'CGHGQTPIPSKGQAF', 'CKISGGPQHAGQTPF', 'CQPGQGIGAKPSHTF', 'CHPTKGGQIAPGQSF', 'CGAPQISGPKGHQTF', 'CSGKIHGPGTQAPQF', 'CIGQQPTAKSHPGGF', 'CPQHPQGKGGSAITF', 'CKQGHSGPTGAQPIF', 'CAPQIKHQGTGPGSF', 'CHQIGQPGAPGKTSF', 'CIPQTGPSGHKGAQF', 'CPGSQAKGPQTGHIF', 'CQSQAKTGPGGIPHF', 'CQHGPIKSGTGPAQF', 'CIAPTGHQQKGSPGF', 'CTAHISKGPPQGGQF', 'CGQGIKTQHGASPPF', 'CIAQPGGPHQGTSKF', 'CHSIAGPQTKGGQPF', 'CPGQKSGIGHAQTPF', 'CPGQTKHGPQIGSAF', 'CGGKGSAQQPIHTPF', 'CHGPQSIAQGKGPTF', 'CQKPHQSGTIPGAGF', 'CQGGTHAPKGQSPIF', 'CITGSHGPQQGKAPF', 'CTGPHQAPIKSGGQF', 'CIQSTQHAKGPPGGF', 'CQGKITPAQPGGSHF', 'CIKAPPGTQGHGSQF', 'CAKGQPTPGQGHISF', 'CQGTKIPGQHPASGF', 'CTKHPIGQGGAPSQF', 'CIGQPTHSAKGGPQF', 'CKGSHPIAQPTQGGF', 'CQGGKPHGSITPAQF', 'CTPQSQGPGIHGAKF', 'CSQGTIKQGGAHPPF', 'CSAQQIGKPHTPGGF', 'CTGASGQPGQKHIPF', 'CGISGPPTQGHAQKF', 'CQHPPISGKGQTGAF', 'CQGAPGQSHGPTKIF', 'CHKGSPQIGQTAGPF', 'CGSIAGTPKQHGPQF', 'CGQPAKQGHSIPTGF', 'CAHGGQPGPQTKISF', 'CSGQPQTGHPIAKGF', 'CTAQHKGPPQSGGIF', 'CGPAPKGQTIQSHGF', 'CSIGQGKPHTAGPQF', 'CPGAIQSPKGHQGTF', 'CGTPAPSGHQIQGKF', 'CTPGPQGGSKIAQHF', 'CPISGHQGKTAPGQF', 'CITHGPPQQAGSKGF', 'CPKSTGAQGIQPGHF', 'CSQPKGAQPITGHGF', 'CHGAGGPTPQSIKQF', 'CPHGIQQSGTKPGAF', 'CGQTKPGHAGISPQF', 'CSQPAQPGKGITHGF', 'CQHTAIKGGQPSGPF', 'CGGSPTQIQAHPGKF', 'CKPGAQGHSIPGQTF', 'CIGPPGHQSATKGQF'] 
        self.database_value = [40, 30, 54, 23, 30, 56, 64, 46, 87, 1, 84, 2, 55, 3, 32, 18, 12, 18, 17, 16, 8, 55, 89, 53, 16, 97, 87, 89, 85, 26, 92, 46, 43, 39, 47, 28, 124, 23, 81, 16, 48, 89, 8, 24, 68, 172, 340, 92, 99, 140, 58, 50, 16, 10, 11, 14, 80, 37, 94, 74, 50, 84, 99, 15, 26, 91, 77, 50, 62, 7, 18, 3, 77, 36, 23, 38, 34, 7, 76, 27, 59, 95, 38, 25, 61, 79, 37, 14, 77, 160, 36, 59, 49, 68, 24, 85, 66, 70, 83, 30, 28, 87, 100, 35, 96, 324, 25, 54, 41, 91, 9, 99, 11, 60, 28, 98, 82, 72, 156, 12, 40, 80, 328, 6, 40, 34, 18, 36, 55, 80, 96, 37, 99, 15, 80, 6, 95, 300, 35, 96, 14, 72, 8, 55, 392, 92, 99, 91, 384, 51, 91, 76, 84, 97, 90, 35, 55, 51, 69, 73, 43, 30, 40, 68, 6, 67, 24, 22, 93, 148, 48, 94, 38, 27, 96, 152, 380, 80, 95, 64, 18, 2, 268, 34, 46, 17, 372, 388, 55, 53, 51, 26, 61, 56, 60, 61, 83, 57, 45, 75, 50, 85, 70, 39, 49, 44, 16, 58, 79, 65, 90, 68, 39, 10, 57, 84, 7, 16, 8, 58, 73, 12, 396, 71, 80, 18, 43, 8, 53, 41, 23, 80, 58, 26, 15, 92, 65, 59, 55, 23, 37, 38, 16, 47, 24, 16, 49, 99, 28, 45, 83, 82, 104, 236, 13, 67, 8, 91, 69, 2, 88, 96, 84, 38, 65, 80, 7, 90, 55, 8, 80, 52, 49, 71, 77, 73, 82, 71, 8, 50, 79, 16, 32, 15, 25, 50, 70, 72, 76, 59, 12, 46, 36, 87, 44, 80, 86, 70, 72, 49, 68, 18, 55, 84, 83, 83, 20, 56, 120, 54, 34, 82, 19, 90, 37, 21, 92, 1, 85, 86, 97, 64, 85, 29, 32, 20, 46, 1, 16, 85, 3, 27, 69, 400, 57, 46, 89, 23, 40, 92, 69, 95, 45, 49, 48, 48, 87, 20, 19, 61, 34, 45, 70, 12, 10, 44, 16, 37, 52, 12, 72, 52, 44, 24, 14, 54, 46, 26, 22, 35, 83, 86, 14, 99, 51, 86, 58, 272, 83, 69, 8, 176, 62, 37, 78, 17, 42, 24, 76, 82, 72, 25, 71, 62, 73, 35, 71, 11, 80, 38, 14, 98, 168, 26, 11, 21, 28, 44, 32, 69, 88, 5, 19, 84, 88, 81, 3, 43, 15, 13, 97, 5, 316, 14, 60, 83, 92, 50, 25, 17, 63, 25, 8, 35, 1, 18, 24, 48, 88, 60, 92, 21, 19, 69, 16, 6, 63, 27, 46, 252, 43, 356, 25, 87, 7, 53, 52, 9, 5, 73, 55, 90, 46, 86, 36, 368, 5, 72, 6, 11, 19, 79, 204, 25, 67, 20, 99, 33, 80, 34, 79, 80, 28, 47, 99, 84, 39, 68, 41, 45, 6, 92, 54, 16, 41, 32, 22, 7, 67, 16, 84, 46, 70, 6, 40, 69, 71, 74, 85, 31, 264, 45, 67, 16, 76, 36, 32, 18, 49, 1, 25, 87, 13, 40, 26, 9, 47, 81, 21, 70, 46, 91, 276, 64, 52, 69, 7, 79, 74, 26, 58, 116, 24, 36, 62, 60, 19, 57, 81, 92, 78, 32, 58, 68, 27, 68, 79, 46, 1, 220, 96, 17, 15, 17, 77, 68, 89, 42, 11, 93, 87, 4, 89, 180, 10, 49, 48, 57, 11, 68, 10, 16, 59, 65, 78, 21, 29, 296, 90, 15, 56, 75, 63, 5, 45, 62, 89, 49, 20, 3, 64, 3, 69, 37, 344, 82, 51, 90, 57, 56, 31, 192, 53, 2, 17, 90, 79, 44, 2, 64, 93, 66, 31, 196, 61, 37, 63, 20, 93, 61, 75, 5, 42, 41, 96, 90, 50, 36, 88, 72, 72, 50, 70, 2, 364, 20, 91, 92, 14, 41, 50, 34, 89, 93, 55, 55, 15, 73, 81, 69, 224, 70, 3, 15, 80, 32, 13, 208, 23, 64, 4, 93, 2, 108, 44, 10, 15, 86, 33, 77, 112, 29, 80, 57, 28, 42, 81, 12, 95, 31, 144, 41, 248, 77, 9, 31, 75, 47, 2, 16, 67, 39, 22, 32, 66, 13, 27, 55, 45, 85, 67, 24, 7, 94, 79, 24, 60, 36, 10, 17, 87, 8, 91, 31, 56, 26, 12, 68, 42, 332, 32, 95, 45, 89, 93, 93, 71, 20, 27, 32, 244, 71, 30, 16, 61, 76, 67, 19, 73, 12, 69, 3, 27, 83, 71, 68, 85, 86, 84, 188, 99, 53, 19, 22, 400, 10, 98, 360, 56, 17, 21, 77, 2, 68, 65, 17, 80, 12, 3, 80, 348, 20, 35, 72, 52, 35, 9, 99, 90, 98, 44, 43, 16, 95, 51, 7, 90, 22, 22, 3, 11, 29, 59, 85, 71, 41, 38, 40, 59, 42, 6, 99, 60, 67, 6, 45, 86, 24, 66, 89, 97, 65, 54, 92, 53, 87, 45, 32, 2, 99, 98, 42, 66, 12, 45, 7, 78, 97, 72, 26, 92, 85, 82, 18, 99, 33, 72, 28, 76, 13, 63, 184, 228, 95, 31, 26, 48, 77, 90, 84, 4, 69, 32, 55, 71, 61, 73, 216, 17, 14, 62, 36, 164, 52, 10, 60, 65, 292, 34, 85, 60, 16, 68, 352, 54, 82, 5, 29, 260, 32, 92, 7, 72, 3, 98, 14, 58, 51, 59, 24, 51, 45, 45, 47, 38, 86, 66, 85, 44, 61, 30, 28, 36, 38, 31, 376, 85, 18, 97, 304, 8, 59, 93, 39, 57, 59, 36, 86, 82, 60, 91, 48, 19, 72, 97, 39, 11, 16, 10, 94, 200, 56, 92, 320, 46, 58, 79, 12, 71, 69, 81, 95, 38, 82, 46, 35, 92, 92, 92, 336, 288, 36, 74, 23, 45, 12, 67, 132, 59, 256, 52, 63, 50, 38, 29, 5, 69, 60, 14, 2, 50, 57, 240, 24, 232, 70, 74, 51, 78, 94, 51, 30, 20, 81, 312, 80, 51, 48, 67, 212, 44, 128, 99, 51, 12, 77, 12, 85, 54, 23, 53, 93, 50, 30, 63, 9, 32, 22, 12, 65, 12, 14, 4, 75, 33, 1, 60, 4, 26, 74, 16, 72, 75, 18, 74, 67, 62, 280, 10, 308, 51, 38, 33, 10, 52, 24, 36, 63, 39, 65, 83, 49, 25, 31, 65, 50, 76, 58, 21, 18, 30, 18, 98, 19, 18, 36, 80, 136, 83, 26, 49, 94, 12, 51, 93, 42, 53, 284, 33, 28, 13, 70, 14, 85, 99, 91, 9, 13, 59, 9, 36, 73, 27, 47, 33, 57, 84, 67, 20, 57, 63, 51, 92, 77, 59, 7, 73, 84, 41, 73, 23, 16, 21, 22, 98, 6, 36, 48, 91, 32]
        self.database_text = ['A', 'B', 'B', 'B', 'B', 'A', 'A', 'A', 'C', 'A', 'C', 'C', 'A', 'D', 'D', 'A', 'B', 'D', 'A', 'A', 'D', 'A', 'B', 'B', 'C', 'E', 'B', 'A', 'B', 'D', 'B', 'B', 'D', 'E', 'D', 'A', 'A', 'B', 'B', 'C', 'C', 'A', 'D', 'B', 'D', 'B', 'A', 'A', 'E', 'B', 'D', 'D', 'E', 'C', 'A', 'D', 'C', 'D', 'C', 'D', 'A', 'A', 'B', 'D', 'B', 'C', 'A', 'A', 'B', 'A', 'C', 'E', 'E', 'E', 'D', 'C', 'E', 'C', 'A', 'D', 'D', 'C', 'E', 'C', 'C', 'D', 'B', 'E', 'A', 'A', 'A', 'B', 'A', 'B', 'A', 'E', 'C', 'B', 'C', 'D', 'B', 'D', 'B', 'C', 'D', 'E', 'D', 'B', 'B', 'B', 'B', 'B', 'B', 'A', 'D', 'A', 'D', 'E', 'C', 'B', 'D', 'E', 'A', 'C', 'B', 'E', 'C', 'E', 'D', 'A', 'E', 'B', 'A', 'B', 'A', 'C', 'B', 'C', 'D', 'C', 'A', 'E', 'B', 'E', 'B', 'B', 'C', 'D', 'A', 'B', 'D', 'E', 'E', 'E', 'C', 'E', 'C', 'E', 'B', 'C', 'C', 'A', 'D', 'B', 'C', 'E', 'A', 'E', 'E', 'A', 'B', 'A', 'B', 'C', 'C', 'A', 'C', 'B', 'B', 'A', 'C', 'B', 'A', 'B', 'D', 'D', 'C', 'B', 'A', 'D', 'A', 'E', 'B', 'B', 'E', 'A', 'A', 'E', 'D', 'D', 'C', 'E', 'A', 'E', 'B', 'D', 'C', 'E', 'A', 'A', 'A', 'A', 'E', 'A', 'B', 'A', 'D', 'E', 'D', 'E', 'A', 'B', 'E', 'C', 'B', 'C', 'C', 'A', 'C', 'D', 'D', 'A', 'C', 'C', 'B', 'C', 'B', 'B', 'B', 'C', 'E', 'B', 'C', 'E', 'B', 'D', 'B', 'E', 'A', 'E', 'D', 'B', 'B', 'C', 'C', 'C', 'E', 'D', 'B', 'E', 'E', 'A', 'A', 'D', 'E', 'E', 'B', 'A', 'B', 'A', 'B', 'A', 'E', 'B', 'E', 'A', 'E', 'D', 'E', 'A', 'E', 'A', 'A', 'C', 'D', 'D', 'E', 'E', 'C', 'C', 'A', 'E', 'B', 'B', 'E', 'A', 'E', 'A', 'A', 'E', 'D', 'B', 'A', 'B', 'E', 'B', 'D', 'C', 'C', 'A', 'C', 'C', 'E', 'B', 'A', 'E', 'E', 'D', 'B', 'A', 'C', 'A', 'E', 'C', 'C', 'D', 'A', 'C', 'A', 'C', 'A', 'C', 'C', 'A', 'B', 'C', 'C', 'E', 'A', 'C', 'B', 'A', 'B', 'C', 'D', 'A', 'D', 'C', 'E', 'E', 'C', 'D', 'A', 'B', 'B', 'D', 'E', 'A', 'A', 'A', 'A', 'A', 'A', 'D', 'C', 'A', 'C', 'A', 'C', 'C', 'C', 'C', 'C', 'B', 'A', 'B', 'D', 'C', 'D', 'A', 'D', 'B', 'E', 'C', 'D', 'E', 'A', 'A', 'A', 'E', 'C', 'B', 'E', 'E', 'B', 'D', 'C', 'D', 'B', 'B', 'D', 'E', 'A', 'C', 'B', 'D', 'A', 'E', 'E', 'A', 'B', 'B', 'D', 'A', 'C', 'D', 'D', 'A', 'A', 'A', 'E', 'C', 'B', 'C', 'B', 'C', 'E', 'E', 'B', 'C', 'C', 'E', 'E', 'D', 'D', 'A', 'A', 'E', 'A', 'C', 'D', 'B', 'E', 'E', 'B', 'C', 'C', 'A', 'C', 'E', 'B', 'B', 'A', 'C', 'A', 'B', 'E', 'D', 'C', 'E', 'C', 'A', 'E', 'D', 'C', 'A', 'B', 'B', 'C', 'A', 'E', 'B', 'A', 'A', 'C', 'D', 'B', 'C', 'D', 'B', 'C', 'A', 'B', 'C', 'E', 'A', 'E', 'C', 'A', 'A', 'C', 'A', 'A', 'A', 'B', 'E', 'A', 'E', 'B', 'A', 'C', 'E', 'C', 'E', 'D', 'B', 'C', 'A', 'C', 'E', 'C', 'B', 'A', 'C', 'E', 'B', 'E', 'B', 'D', 'A', 'D', 'C', 'D', 'D', 'E', 'A', 'A', 'A', 'C', 'A', 'A', 'C', 'A', 'D', 'D', 'C', 'C', 'D', 'B', 'E', 'B', 'A', 'B', 'A', 'B', 'A', 'C', 'A', 'D', 'C', 'E', 'E', 'E', 'B', 'A', 'C', 'A', 'C', 'A', 'A', 'A', 'C', 'E', 'C', 'E', 'A', 'A', 'C', 'D', 'A', 'E', 'D', 'B', 'E', 'C', 'A', 'D', 'D', 'C', 'C', 'C', 'B', 'C', 'A', 'B', 'C', 'B', 'A', 'B', 'B', 'B', 'E', 'D', 'B', 'A', 'D', 'C', 'C', 'A', 'E', 'B', 'D', 'E', 'E', 'C', 'A', 'B', 'D', 'B', 'E', 'A', 'C', 'A', 'C', 'B', 'E', 'B', 'C', 'D', 'C', 'B', 'E', 'A', 'A', 'B', 'C', 'E', 'A', 'D', 'E', 'D', 'D', 'D', 'C', 'A', 'D', 'C', 'B', 'A', 'B', 'A', 'A', 'D', 'C', 'A', 'C', 'D', 'B', 'A', 'C', 'A', 'E', 'D', 'B', 'D', 'D', 'A', 'C', 'A', 'D', 'A', 'B', 'B', 'E', 'D', 'B', 'B', 'B', 'E', 'E', 'C', 'A', 'B', 'E', 'E', 'C', 'C', 'C', 'A', 'B', 'A', 'C', 'D', 'C', 'A', 'B', 'A', 'D', 'A', 'C', 'E', 'E', 'B', 'A', 'B', 'D', 'D', 'D', 'D', 'C', 'B', 'E', 'B', 'B', 'B', 'B', 'D', 'A', 'E', 'C', 'B', 'E', 'C', 'D', 'A', 'B', 'B', 'A', 'A', 'E', 'B', 'D', 'A', 'E', 'B', 'C', 'E', 'E', 'A', 'A', 'C', 'C', 'A', 'A', 'E', 'A', 'E', 'A', 'D', 'E', 'B', 'D', 'A', 'D', 'B', 'C', 'B', 'E', 'A', 'A', 'E', 'B', 'A', 'C', 'D', 'B', 'C', 'E', 'C', 'A', 'B', 'D', 'D', 'E', 'A', 'C', 'D', 'E', 'A', 'E', 'C', 'D', 'C', 'D', 'D', 'C', 'B', 'E', 'D', 'A', 'A', 'D', 'E', 'B', 'A', 'C', 'B', 'A', 'A', 'B', 'C', 'C', 'D', 'C', 'C', 'B', 'C', 'E', 'C', 'B', 'C', 'D', 'E', 'D', 'C', 'E', 'B', 'D', 'C', 'A', 'A', 'D', 'E', 'A', 'D', 'D', 'C', 'E', 'A', 'D', 'E', 'A', 'C', 'B', 'B', 'C', 'C', 'C', 'B', 'D', 'B', 'B', 'C', 'B', 'D', 'A', 'C', 'D', 'D', 'E', 'D', 'C', 'B', 'A', 'A', 'B', 'C', 'B', 'C', 'C', 'E', 'A', 'C', 'E', 'E', 'A', 'C', 'E', 'E', 'D', 'E', 'A', 'B', 'B', 'B', 'B', 'E', 'E', 'A', 'C', 'C', 'A', 'C', 'D', 'E', 'B', 'A', 'A', 'C', 'E', 'B', 'A', 'B', 'B', 'B', 'E', 'D', 'B', 'A', 'A', 'B', 'B', 'E', 'C', 'B', 'A', 'A', 'C', 'E', 'C', 'B', 'A', 'B', 'B', 'A', 'E', 'D', 'E', 'A', 'D', 'E', 'D', 'D', 'D', 'B', 'A', 'A', 'D', 'E', 'A', 'B', 'C', 'E', 'E', 'C', 'E', 'D', 'A', 'A', 'D', 'B', 'A', 'C', 'D', 'A', 'D', 'D', 'A', 'A', 'B', 'C', 'B', 'E', 'B', 'E', 'B', 'B', 'E', 'B', 'A', 'E', 'C', 'D', 'D', 'A', 'C', 'A', 'E', 'B', 'C', 'E', 'A', 'D', 'C', 'C', 'C', 'D', 'A', 'B', 'A', 'C', 'A', 'E', 'B', 'A', 'A', 'D', 'A', 'E', 'C', 'B', 'D', 'A', 'C', 'A', 'E', 'C', 'A', 'B', 'A', 'C', 'C', 'D', 'B', 'A', 'B', 'A', 'E', 'A', 'B', 'B', 'C', 'C', 'C', 'A', 'C', 'C', 'E', 'B', 'C', 'B', 'C', 'A', 'C', 'C', 'B', 'B', 'D', 'B', 'C', 'B', 'C', 'C', 'E', 'D', 'A', 'B', 'E', 'C', 'D', 'B', 'A', 'A', 'D', 'B', 'E', 'C', 'B', 'E', 'C', 'A', 'A', 'A', 'E', 'D', 'C', 'D', 'E', 'A', 'D', 'A', 'B', 'D', 'C', 'C', 'C', 'D', 'A', 'C', 'E', 'A', 'C', 'A', 'E', 'D', 'A', 'D', 'B', 'A', 'E', 'E', 'B', 'A', 'B', 'E', 'D', 'D', 'B', 'D', 'A', 'B', 'D', 'E', 'E', 'A', 'E', 'A', 'E', 'D', 'E', 'A', 'A', 'A', 'E', 'B', 'B', 'E', 'C', 'B', 'C', 'E', 'E', 'B', 'E', 'E', 'E', 'B', 'C', 'D', 'A', 'C', 'E', 'E', 'E', 'D', 'D', 'C', 'E', 'B', 'D']

        self.DB_dataframe = pd.DataFrame()
        self.DB_dataframe[self.database_seq_name] = self.database_seq
        self.DB_dataframe[self.database_value_name] = self.database_value
        self.DB_dataframe[self.database_text_name] = self.database_text

class QueryFile:
    def __init__(self):
        self.seq = ['CPTGGAQGKHIPQSF', 'CKASIPQGTHGGQPF', 'CPIQGHPASQGGKTF', 'CATGIHGQSQPKPGF', 'CPKTGQQSAHGGPIF', 'CPQPGGKIAQGHSTF', 'CPGISPQGAKTQHGF', 'CQPQHPKTGGGIASF', 'CGKSQGPQGPAHITF', 'CTGGPSIHPQAKQGF', 'CITHGAGPPSQGKQF', 'CPHQQGGIASTKGPF', 'CIGSQPGPHKTQGAF', 'CGKSPHATPQIGGQF', 'CTQSKIGQAGHPGPF', 'CGPASTHIQQPGGKF', 'CGIKQTSGAHGPPQF', 'CITGSHGPQQGKAPF', 'CTGSPGPHAQKQIGF', 'CPQHGGISTPKQGAF', 'CGQPGTQIGSAKPHF', 'CQPQKGPASTIGHGF', 'CKQGPSGPTHAQGIF', 'CAPQQTPGSIKHGGF', 'CHPIQPKGTAGQGSF', 'CKIPGQPSQHGGATF', 'CAQGQPKPGHTGISF', 'CGGPTSQHKPAQGIF', 'CPAGPKQITQSGGHF', 'CGPPGQAHSGTQIKF', 'CGHGAGPIQQKTPSF', 'CIGPQAHQTGPKGSF', 'CQHGPIKSGTGPAQF', 'CKTGHSIGPQAPGQF', 'CQTQPGKGIHSGAPF', 'CSGQAPHPGKGQTIF', 'CHKTGGPPSQAQGIF', 'CQGSPIGQGATPKHF', 'CGGQKSQTIPGPAHF', 'CTQASHGPPQKGIGF', 'CKSTGAQHGPPIGQF', 'CSPQHAQGIGTPGKF', 'CPKISTHQQPGAGGF', 'CKHSGGPIAQQPGTF', 'CSAPPQGGGTIHQKF', 'CKTQSAIHGPQGPGF', 'CHGSQTPGGPIQKAF', 'CSGGQPGPAKTHIQF', 'CAKGQGPQPIHSGTF', 'CHGKGITPQAGSPQF', 'CGQPQPTAHGIGSKF', 'CPGKQTIAHQSGGPF', 'CQTQHGIPGSKPAGF', 'CQGIPPSGKAQHGTF', 'CHGQGKQTIAPPGSF', 'CAGHPGQSPIQTKGF', 'CQPGATSKGPGQHIF', 'CTHQGSAIKPPGGQF', 'CGIKTGPQQPAHSGF', 'CTHSPPGGGKAQQIF', 'CGSQPPITKAHGQGF', 'CPKGHQGGIQATSPF', 'CAGQITGHQKPPGSF', 'CSAPTIHQQGGPGKF', 'CPQQKGGGHTASIPF', 'CPQTSGAIHQKGPGF', 'CQQKPSAIGHGGPTF', 'CHQPAPIGTKQGSGF', 'CIKPHQASGGGTPQF', 'CQKPHQSGTIPGAGF', 'CIQKPSHTGPGQAGF', 'CGSAGQGPPHTQIKF', 'CTQGGSGQPHIKPAF', 'CAGHPPQGTKQGISF', 'CIPSAQPQGHKGGTF', 'CIPGQHAGPKGQTSF', 'CAQQSTKGPHGIGPF', 'CPPATGQHQSIGKGF', 'CGGHIPKSPAQQTGF', 'CIGPGKTPGHAQQSF', 'CSQKPGTIHQGAGPF', 'CAGPPKGQGQIHTSF', 'CKHIQGPGSQGPTAF', 'CSGQTGGPIKPHAQF', 'CTGQGHQPGPISKAF', 'CPGAKQIGTPSHQGF', 'CGSPQPIKTHGAGQF', 'CHQPGTPGKSGAQIF', 'CIHQATGPQKPGSGF', 'CQSKPGAGGHPTQIF', 'CGQSPAGGKHQTPIF', 'CTGPQQKHGAGSPIF', 'CAQTSGKHGIQPPGF', 'CKSIPAPHGGGQTQF', 'CKTIGPQGSGQAHPF', 'CQHQTAPKIPSGGGF', 'CQKPPGTGGHQISAF', 'CQGAIHSKGQPTGPF', 'CGGTPQSQHAIPKGF', 'CGKHQAPPTQGSGIF']
        self.info = [62, 6, 83, 22, 73, 43, 7, 92, 9, 77, 30, 68, 29, 52, 69, 43, 25, 11, 14, 42, 46, 69, 48, 19, 91, 55, 51, 34, 85, 34, 64, 84, 66, 73, 76, 72, 10, 20, 60, 67, 71, 30, 11, 46, 73, 23, 6, 45, 58, 12, 35, 48, 60, 38, 42, 35, 3, 77, 19, 3, 20, 48, 63, 1, 95, 58, 7, 53, 74, 84, 75, 46, 55, 86, 66, 24, 28, 24, 49, 56, 31, 95, 49, 58, 53, 61, 59, 98, 47, 20, 17, 28, 5, 6, 92, 38, 50, 50, 43, 6]

        self.DB_dataframe = pd.DataFrame()
        self.DB_dataframe['seq'] = self.seq
        self.DB_dataframe['info'] = self.info

class ExactMatchTrueFile:
    def __init__(self):
        super().__init__()
        self.seq = ['CPTGGAQGKHIPQSF', 'CKASIPQGTHGGQPF', 'CPIQGHPASQGGKTF', 'CATGIHGQSQPKPGF', 'CPKTGQQSAHGGPIF', 'CPQPGGKIAQGHSTF', 'CPGISPQGAKTQHGF', 'CQPQHPKTGGGIASF', 'CGKSQGPQGPAHITF', 'CTGGPSIHPQAKQGF', 'CITHGAGPPSQGKQF', 'CPHQQGGIASTKGPF', 'CIGSQPGPHKTQGAF', 'CGKSPHATPQIGGQF', 'CTQSKIGQAGHPGPF', 'CGPASTHIQQPGGKF', 'CGIKQTSGAHGPPQF', 'CITGSHGPQQGKAPF', 'CTGSPGPHAQKQIGF', 'CPQHGGISTPKQGAF', 'CGQPGTQIGSAKPHF', 'CQPQKGPASTIGHGF', 'CKQGPSGPTHAQGIF', 'CAPQQTPGSIKHGGF', 'CHPIQPKGTAGQGSF', 'CKIPGQPSQHGGATF', 'CAQGQPKPGHTGISF', 'CGGPTSQHKPAQGIF', 'CPAGPKQITQSGGHF', 'CGPPGQAHSGTQIKF', 'CGHGAGPIQQKTPSF', 'CIGPQAHQTGPKGSF', 'CQHGPIKSGTGPAQF', 'CKTGHSIGPQAPGQF', 'CQTQPGKGIHSGAPF', 'CSGQAPHPGKGQTIF', 'CHKTGGPPSQAQGIF', 'CQGSPIGQGATPKHF', 'CGGQKSQTIPGPAHF', 'CTQASHGPPQKGIGF', 'CKSTGAQHGPPIGQF', 'CSPQHAQGIGTPGKF', 'CPKISTHQQPGAGGF', 'CKHSGGPIAQQPGTF', 'CSAPPQGGGTIHQKF', 'CKTQSAIHGPQGPGF', 'CHGSQTPGGPIQKAF', 'CSGGQPGPAKTHIQF', 'CAKGQGPQPIHSGTF', 'CHGKGITPQAGSPQF', 'CGQPQPTAHGIGSKF', 'CPGKQTIAHQSGGPF', 'CQTQHGIPGSKPAGF', 'CQGIPPSGKAQHGTF', 'CHGQGKQTIAPPGSF', 'CAGHPGQSPIQTKGF', 'CQPGATSKGPGQHIF', 'CTHQGSAIKPPGGQF', 'CGIKTGPQQPAHSGF', 'CTHSPPGGGKAQQIF', 'CGSQPPITKAHGQGF', 'CPKGHQGGIQATSPF', 'CAGQITGHQKPPGSF', 'CSAPTIHQQGGPGKF', 'CPQQKGGGHTASIPF', 'CPQTSGAIHQKGPGF', 'CQQKPSAIGHGGPTF', 'CHQPAPIGTKQGSGF', 'CIKPHQASGGGTPQF', 'CQKPHQSGTIPGAGF', 'CIQKPSHTGPGQAGF', 'CGSAGQGPPHTQIKF', 'CTQGGSGQPHIKPAF', 'CAGHPPQGTKQGISF', 'CIPSAQPQGHKGGTF', 'CIPGQHAGPKGQTSF', 'CAQQSTKGPHGIGPF', 'CPPATGQHQSIGKGF', 'CGGHIPKSPAQQTGF', 'CIGPGKTPGHAQQSF', 'CSQKPGTIHQGAGPF', 'CAGPPKGQGQIHTSF', 'CKHIQGPGSQGPTAF', 'CSGQTGGPIKPHAQF', 'CTGQGHQPGPISKAF', 'CPGAKQIGTPSHQGF', 'CGSPQPIKTHGAGQF', 'CHQPGTPGKSGAQIF', 'CIHQATGPQKPGSGF', 'CQSKPGAGGHPTQIF', 'CGQSPAGGKHQTPIF', 'CTGPQQKHGAGSPIF', 'CAQTSGKHGIQPPGF', 'CKSIPAPHGGGQTQF', 'CKTIGPQGSGQAHPF', 'CQHQTAPKIPSGGGF', 'CQKPPGTGGHQISAF', 'CQGAIHSKGQPTGPF', 'CGGTPQSQHAIPKGF', 'CGKHQAPPTQGSGIF']
        self.info = [62, 6, 83, 22, 73, 43, 7, 92, 9, 77, 30, 68, 29, 52, 69, 43, 25, 11, 14, 42, 46, 69, 48, 19, 91, 55, 51, 34, 85, 34, 64, 84, 66, 73, 76, 72, 10, 20, 60, 67, 71, 30, 11, 46, 73, 23, 6, 45, 58, 12, 35, 48, 60, 38, 42, 35, 3, 77, 19, 3, 20, 48, 63, 1, 95, 58, 7, 53, 74, 84, 75, 46, 55, 86, 66, 24, 28, 24, 49, 56, 31, 95, 49, 58, 53, 61, 59, 98, 47, 20, 17, 28, 5, 6, 92, 38, 50, 50, 43, 6]
        self.results = ['[seq: CPTGGAQGKHIPQSF (Value_identifier: 8) (Text_identifier: A)]\n', '[seq: CKASIPQGTHGGQPF (Value_identifier: 10) (Text_identifier: C)]\n[seq: CKASIPQGTHGGQPF (Value_identifier: 12) (Text_identifier: C)]\n', '[seq: CPIQGHPASQGGKTF (Value_identifier: 16) (Text_identifier: A)]\n[seq: CPIQGHPASQGGKTF (Value_identifier: 12) (Text_identifier: A)]\n', '[seq: CATGIHGQSQPKPGF (Value_identifier: 20) (Text_identifier: C)]\n[seq: CATGIHGQSQPKPGF (Value_identifier: 14) (Text_identifier: A)]\n', '[seq: CPKTGQQSAHGGPIF (Value_identifier: 16) (Text_identifier: A)]\n[seq: CPKTGQQSAHGGPIF (Value_identifier: 24) (Text_identifier: A)]\n', '[seq: CPQPGGKIAQGHSTF (Value_identifier: 18) (Text_identifier: C)]\n[seq: CPQPGGKIAQGHSTF (Value_identifier: 28) (Text_identifier: B)]\n', '[seq: CPGISPQGAKTQHGF (Value_identifier: 20) (Text_identifier: A)]\n[seq: CPGISPQGAKTQHGF (Value_identifier: 32) (Text_identifier: B)]\n', '[seq: CQPQHPKTGGGIASF (Value_identifier: 36) (Text_identifier: E)]\n[seq: CQPQHPKTGGGIASF (Value_identifier: 22) (Text_identifier: A)]\n', '[seq: CGKSQGPQGPAHITF (Value_identifier: 40) (Text_identifier: A)]\n[seq: CGKSQGPQGPAHITF (Value_identifier: 24) (Text_identifier: A)]\n', '[seq: CTGGPSIHPQAKQGF (Value_identifier: 44) (Text_identifier: A)]\n', '[seq: CITHGAGPPSQGKQF (Value_identifier: 48) (Text_identifier: C)]\n', '[seq: CPHQQGGIASTKGPF (Value_identifier: 52) (Text_identifier: A)]\n', '[seq: CIGSQPGPHKTQGAF (Value_identifier: 56) (Text_identifier: C)]\n', '[seq: CGKSPHATPQIGGQF (Value_identifier: 60) (Text_identifier: A)]\n', '[seq: CTQSKIGQAGHPGPF (Value_identifier: 64) (Text_identifier: B)]\n', '[seq: CGPASTHIQQPGGKF (Value_identifier: 68) (Text_identifier: B)]\n', '[seq: CGIKQTSGAHGPPQF (Value_identifier: 72) (Text_identifier: E)]\n[seq: CGIKQTSGAHGPPQF (Value_identifier: 26) (Text_identifier: C)]\n', '[seq: CITGSHGPQQGKAPF (Value_identifier: 76) (Text_identifier: A)]\n[seq: CITGSHGPQQGKAPF (Value_identifier: 28) (Text_identifier: A)]\n', '[seq: CTGSPGPHAQKQIGF (Value_identifier: 30) (Text_identifier: A)]\n[seq: CTGSPGPHAQKQIGF (Value_identifier: 80) (Text_identifier: A)]\n', '[seq: CPQHGGISTPKQGAF (Value_identifier: 32) (Text_identifier: A)]\n[seq: CPQHGGISTPKQGAF (Value_identifier: 84) (Text_identifier: C)]\n', '[seq: CGQPGTQIGSAKPHF (Value_identifier: 34) (Text_identifier: C)]\n[seq: CGQPGTQIGSAKPHF (Value_identifier: 88) (Text_identifier: A)]\n', '[seq: CQPQKGPASTIGHGF (Value_identifier: 92) (Text_identifier: C)]\n[seq: CQPQKGPASTIGHGF (Value_identifier: 36) (Text_identifier: A)]\n', '[seq: CKQGPSGPTHAQGIF (Value_identifier: 96) (Text_identifier: A)]\n[seq: CKQGPSGPTHAQGIF (Value_identifier: 38) (Text_identifier: A)]\n', '[seq: CAPQQTPGSIKHGGF (Value_identifier: 40) (Text_identifier: A)]\n[seq: CAPQQTPGSIKHGGF (Value_identifier: 100) (Text_identifier: B)]\n', '[seq: CHPIQPKGTAGQGSF (Value_identifier: 104) (Text_identifier: B)]\n[seq: CHPIQPKGTAGQGSF (Value_identifier: 41) (Text_identifier: E)]\n', '[seq: CKIPGQPSQHGGATF (Value_identifier: 108) (Text_identifier: E)]\n', '[seq: CAQGQPKPGHTGISF (Value_identifier: 112) (Text_identifier: A)]\n', '[seq: CGGPTSQHKPAQGIF (Value_identifier: 116) (Text_identifier: A)]\n', '[seq: CPAGPKQITQSGGHF (Value_identifier: 120) (Text_identifier: C)]\n', '[seq: CGPPGQAHSGTQIKF (Value_identifier: 124) (Text_identifier: A)]\n', '[seq: CGHGAGPIQQKTPSF (Value_identifier: 128) (Text_identifier: C)]\n', '[seq: CIGPQAHQTGPKGSF (Value_identifier: 132) (Text_identifier: A)]\n', '[seq: CQHGPIKSGTGPAQF (Value_identifier: 136) (Text_identifier: B)]\n', '[seq: CKTGHSIGPQAPGQF (Value_identifier: 140) (Text_identifier: B)]\n', '[seq: CQTQPGKGIHSGAPF (Value_identifier: 144) (Text_identifier: E)]\n', '[seq: CSGQAPHPGKGQTIF (Value_identifier: 148) (Text_identifier: A)]\n', '[seq: CHKTGGPPSQAQGIF (Value_identifier: 152) (Text_identifier: A)]\n', '[seq: CQGSPIGQGATPKHF (Value_identifier: 156) (Text_identifier: C)]\n', '[seq: CGGQKSQTIPGPAHF (Value_identifier: 160) (Text_identifier: A)]\n', '[seq: CTQASHGPPQKGIGF (Value_identifier: 164) (Text_identifier: C)]\n', '[seq: CKSTGAQHGPPIGQF (Value_identifier: 168) (Text_identifier: A)]\n', '[seq: CSPQHAQGIGTPGKF (Value_identifier: 172) (Text_identifier: B)]\n', '[seq: CPKISTHQQPGAGGF (Value_identifier: 176) (Text_identifier: B)]\n', '[seq: CKHSGGPIAQQPGTF (Value_identifier: 180) (Text_identifier: E)]\n', '[seq: CSAPPQGGGTIHQKF (Value_identifier: 184) (Text_identifier: A)]\n', '[seq: CKTQSAIHGPQGPGF (Value_identifier: 188) (Text_identifier: A)]\n', '[seq: CHGSQTPGGPIQKAF (Value_identifier: 192) (Text_identifier: C)]\n', '[seq: CSGGQPGPAKTHIQF (Value_identifier: 196) (Text_identifier: A)]\n', '[seq: CAKGQGPQPIHSGTF (Value_identifier: 200) (Text_identifier: C)]\n', '[seq: CHGKGITPQAGSPQF (Value_identifier: 204) (Text_identifier: A)]\n', '[seq: CGQPQPTAHGIGSKF (Value_identifier: 208) (Text_identifier: B)]\n', '[seq: CPGKQTIAHQSGGPF (Value_identifier: 212) (Text_identifier: B)]\n', '[seq: CQTQHGIPGSKPAGF (Value_identifier: 216) (Text_identifier: E)]\n', '[seq: CQGIPPSGKAQHGTF (Value_identifier: 220) (Text_identifier: A)]\n', '[seq: CHGQGKQTIAPPGSF (Value_identifier: 224) (Text_identifier: A)]\n', '[seq: CAGHPGQSPIQTKGF (Value_identifier: 228) (Text_identifier: C)]\n', '[seq: CQPGATSKGPGQHIF (Value_identifier: 232) (Text_identifier: A)]\n', '[seq: CTHQGSAIKPPGGQF (Value_identifier: 236) (Text_identifier: C)]\n', '[seq: CGIKTGPQQPAHSGF (Value_identifier: 240) (Text_identifier: A)]\n', '[seq: CTHSPPGGGKAQQIF (Value_identifier: 244) (Text_identifier: B)]\n', '[seq: CGSQPPITKAHGQGF (Value_identifier: 248) (Text_identifier: B)]\n', '[seq: CPKGHQGGIQATSPF (Value_identifier: 252) (Text_identifier: E)]\n', '[seq: CAGQITGHQKPPGSF (Value_identifier: 256) (Text_identifier: A)]\n', '[seq: CSAPTIHQQGGPGKF (Value_identifier: 260) (Text_identifier: A)]\n', '[seq: CPQQKGGGHTASIPF (Value_identifier: 264) (Text_identifier: C)]\n', '[seq: CPQTSGAIHQKGPGF (Value_identifier: 268) (Text_identifier: A)]\n', '[seq: CQQKPSAIGHGGPTF (Value_identifier: 272) (Text_identifier: C)]\n', '[seq: CHQPAPIGTKQGSGF (Value_identifier: 276) (Text_identifier: A)]\n', '[seq: CIKPHQASGGGTPQF (Value_identifier: 280) (Text_identifier: B)]\n', '[seq: CQKPHQSGTIPGAGF (Value_identifier: 284) (Text_identifier: B)]\n', '[seq: CIQKPSHTGPGQAGF (Value_identifier: 288) (Text_identifier: E)]\n', '[seq: CGSAGQGPPHTQIKF (Value_identifier: 292) (Text_identifier: A)]\n', '[seq: CTQGGSGQPHIKPAF (Value_identifier: 296) (Text_identifier: A)]\n', '[seq: CAGHPPQGTKQGISF (Value_identifier: 300) (Text_identifier: C)]\n', '[seq: CIPSAQPQGHKGGTF (Value_identifier: 304) (Text_identifier: A)]\n', '[seq: CIPGQHAGPKGQTSF (Value_identifier: 308) (Text_identifier: C)]\n', '[seq: CAQQSTKGPHGIGPF (Value_identifier: 312) (Text_identifier: A)]\n', '[seq: CPPATGQHQSIGKGF (Value_identifier: 316) (Text_identifier: B)]\n', '[seq: CGGHIPKSPAQQTGF (Value_identifier: 320) (Text_identifier: B)]\n', '[seq: CIGPGKTPGHAQQSF (Value_identifier: 324) (Text_identifier: E)]\n', '[seq: CSQKPGTIHQGAGPF (Value_identifier: 328) (Text_identifier: A)]\n', '[seq: CAGPPKGQGQIHTSF (Value_identifier: 332) (Text_identifier: A)]\n', '[seq: CKHIQGPGSQGPTAF (Value_identifier: 336) (Text_identifier: C)]\n', '[seq: CSGQTGGPIKPHAQF (Value_identifier: 340) (Text_identifier: A)]\n', '[seq: CTGQGHQPGPISKAF (Value_identifier: 344) (Text_identifier: C)]\n', '[seq: CPGAKQIGTPSHQGF (Value_identifier: 348) (Text_identifier: A)]\n', '[seq: CGSPQPIKTHGAGQF (Value_identifier: 352) (Text_identifier: B)]\n', '[seq: CHQPGTPGKSGAQIF (Value_identifier: 356) (Text_identifier: B)]\n', '[seq: CIHQATGPQKPGSGF (Value_identifier: 360) (Text_identifier: E)]\n', '[seq: CQSKPGAGGHPTQIF (Value_identifier: 364) (Text_identifier: A)]\n', '[seq: CGQSPAGGKHQTPIF (Value_identifier: 368) (Text_identifier: A)]\n', '[seq: CTGPQQKHGAGSPIF (Value_identifier: 372) (Text_identifier: C)]\n', '[seq: CAQTSGKHGIQPPGF (Value_identifier: 376) (Text_identifier: A)]\n', '[seq: CKSIPAPHGGGQTQF (Value_identifier: 380) (Text_identifier: C)]\n', '[seq: CKTIGPQGSGQAHPF (Value_identifier: 384) (Text_identifier: A)]\n', '[seq: CQHQTAPKIPSGGGF (Value_identifier: 388) (Text_identifier: B)]\n', '[seq: CQKPPGTGGHQISAF (Value_identifier: 392) (Text_identifier: B)]\n', '[seq: CQGAIHSKGQPTGPF (Value_identifier: 396) (Text_identifier: E)]\n', '[seq: CGGTPQSQHAIPKGF (Value_identifier: 400) (Text_identifier: A)]\n', '[seq: CGKHQAPPTQGSGIF (Value_identifier: 400) (Text_identifier: A)]\n']


        self.DB_dataframe = pd.DataFrame()
        self.DB_dataframe['seq'] = self.seq
        self.DB_dataframe['info'] = self.info
        self.DB_dataframe['results'] = self.results

class AlignerTrueFile:
    def __init__(self):
        self.seq = ['CPTGGAQGKHIPQSF', 'CKASIPQGTHGGQPF', 'CPIQGHPASQGGKTF', 'CATGIHGQSQPKPGF', 'CPKTGQQSAHGGPIF', 'CPQPGGKIAQGHSTF', 'CPGISPQGAKTQHGF', 'CQPQHPKTGGGIASF', 'CGKSQGPQGPAHITF', 'CTGGPSIHPQAKQGF', 'CITHGAGPPSQGKQF', 'CPHQQGGIASTKGPF', 'CIGSQPGPHKTQGAF', 'CGKSPHATPQIGGQF', 'CTQSKIGQAGHPGPF', 'CGPASTHIQQPGGKF', 'CGIKQTSGAHGPPQF', 'CITGSHGPQQGKAPF', 'CTGSPGPHAQKQIGF', 'CPQHGGISTPKQGAF', 'CGQPGTQIGSAKPHF', 'CQPQKGPASTIGHGF', 'CKQGPSGPTHAQGIF', 'CAPQQTPGSIKHGGF', 'CHPIQPKGTAGQGSF', 'CKIPGQPSQHGGATF', 'CAQGQPKPGHTGISF', 'CGGPTSQHKPAQGIF', 'CPAGPKQITQSGGHF', 'CGPPGQAHSGTQIKF', 'CGHGAGPIQQKTPSF', 'CIGPQAHQTGPKGSF', 'CQHGPIKSGTGPAQF', 'CKTGHSIGPQAPGQF', 'CQTQPGKGIHSGAPF', 'CSGQAPHPGKGQTIF', 'CHKTGGPPSQAQGIF', 'CQGSPIGQGATPKHF', 'CGGQKSQTIPGPAHF', 'CTQASHGPPQKGIGF', 'CKSTGAQHGPPIGQF', 'CSPQHAQGIGTPGKF', 'CPKISTHQQPGAGGF', 'CKHSGGPIAQQPGTF', 'CSAPPQGGGTIHQKF', 'CKTQSAIHGPQGPGF', 'CHGSQTPGGPIQKAF', 'CSGGQPGPAKTHIQF', 'CAKGQGPQPIHSGTF', 'CHGKGITPQAGSPQF', 'CGQPQPTAHGIGSKF', 'CPGKQTIAHQSGGPF', 'CQTQHGIPGSKPAGF', 'CQGIPPSGKAQHGTF', 'CHGQGKQTIAPPGSF', 'CAGHPGQSPIQTKGF', 'CQPGATSKGPGQHIF', 'CTHQGSAIKPPGGQF', 'CGIKTGPQQPAHSGF', 'CTHSPPGGGKAQQIF', 'CGSQPPITKAHGQGF', 'CPKGHQGGIQATSPF', 'CAGQITGHQKPPGSF', 'CSAPTIHQQGGPGKF', 'CPQQKGGGHTASIPF', 'CPQTSGAIHQKGPGF', 'CQQKPSAIGHGGPTF', 'CHQPAPIGTKQGSGF', 'CIKPHQASGGGTPQF', 'CQKPHQSGTIPGAGF', 'CIQKPSHTGPGQAGF', 'CGSAGQGPPHTQIKF', 'CTQGGSGQPHIKPAF', 'CAGHPPQGTKQGISF', 'CIPSAQPQGHKGGTF', 'CIPGQHAGPKGQTSF', 'CAQQSTKGPHGIGPF', 'CPPATGQHQSIGKGF', 'CGGHIPKSPAQQTGF', 'CIGPGKTPGHAQQSF', 'CSQKPGTIHQGAGPF', 'CAGPPKGQGQIHTSF', 'CKHIQGPGSQGPTAF', 'CSGQTGGPIKPHAQF', 'CTGQGHQPGPISKAF', 'CPGAKQIGTPSHQGF', 'CGSPQPIKTHGAGQF', 'CHQPGTPGKSGAQIF', 'CIHQATGPQKPGSGF', 'CQSKPGAGGHPTQIF', 'CGQSPAGGKHQTPIF', 'CTGPQQKHGAGSPIF', 'CAQTSGKHGIQPPGF', 'CKSIPAPHGGGQTQF', 'CKTIGPQGSGQAHPF', 'CQHQTAPKIPSGGGF', 'CQKPPGTGGHQISAF', 'CQGAIHSKGQPTGPF', 'CGGTPQSQHAIPKGF', 'CGKHQAPPTQGSGIF']
        self.info = [62, 6, 83, 22, 73, 43, 7, 92, 9, 77, 30, 68, 29, 52, 69, 43, 25, 11, 14, 42, 46, 69, 48, 19, 91, 55, 51, 34, 85, 34, 64, 84, 66, 73, 76, 72, 10, 20, 60, 67, 71, 30, 11, 46, 73, 23, 6, 45, 58, 12, 35, 48, 60, 38, 42, 35, 3, 77, 19, 3, 20, 48, 63, 1, 95, 58, 7, 53, 74, 84, 75, 46, 55, 86, 66, 24, 28, 24, 49, 56, 31, 95, 49, 58, 53, 61, 59, 98, 47, 20, 17, 28, 5, 6, 92, 38, 50, 50, 43, 6]
        self.results = ['[seq: CPTGGAQGKHIPQSF (Value_identifier: 8) (Text_identifier: A)]\n[seq: CPTAGAQGKHIPQSF (Value_identifier: 8) (Text_identifier: A)]\n', '[seq: CKASIPQGTHGGQPF (Value_identifier: 10) (Text_identifier: C)]\n[seq: CKASIPQGTHGGQPF (Value_identifier: 12) (Text_identifier: C)]\n', '[seq: CPIQGHPASQGGKTF (Value_identifier: 16) (Text_identifier: A)]\n[seq: CPIQGHPASQGGKTF (Value_identifier: 12) (Text_identifier: A)]\n', '[seq: CATGIHGQSQPKPGF (Value_identifier: 20) (Text_identifier: C)]\n[seq: CATGIHGQSQPKPGF (Value_identifier: 14) (Text_identifier: A)]\n', '[seq: CPKTGQQSAHGGPIF (Value_identifier: 16) (Text_identifier: A)]\n[seq: CPKTGQQSAHGGPIF (Value_identifier: 24) (Text_identifier: A)]\n', '[seq: CPQPGGKIAQGHSTF (Value_identifier: 18) (Text_identifier: C)]\n[seq: CPQPGGKIAQGHSTF (Value_identifier: 28) (Text_identifier: B)]\n', '[seq: CPGISPQGAKTQHGF (Value_identifier: 20) (Text_identifier: A)]\n[seq: CPGISPQGAKTQHGF (Value_identifier: 32) (Text_identifier: B)]\n', '[seq: CQPQHPKTGGGIASF (Value_identifier: 36) (Text_identifier: E)]\n[seq: CQPQHPKTGGGIASF (Value_identifier: 22) (Text_identifier: A)]\n', '[seq: CGKSQGPQGPAHITF (Value_identifier: 40) (Text_identifier: A)]\n[seq: CGKSQGPQGPAHITF (Value_identifier: 24) (Text_identifier: A)]\n', '[seq: CTGGPSIHPQAKQGF (Value_identifier: 44) (Text_identifier: A)]\n', '[seq: CITHGAGPPSQGKQF (Value_identifier: 48) (Text_identifier: C)]\n', '[seq: CPHQQGGIASTKGPF (Value_identifier: 52) (Text_identifier: A)]\n', '[seq: CIGSQPGPHKTQGAF (Value_identifier: 56) (Text_identifier: C)]\n', '[seq: CGKSPHATPQIGGQF (Value_identifier: 60) (Text_identifier: A)]\n', '[seq: CTQSKIGQAGHPGPF (Value_identifier: 64) (Text_identifier: B)]\n', '[seq: CGPASTHIQQPGGKF (Value_identifier: 68) (Text_identifier: B)]\n', '[seq: CGIKQTSGAHGPPQF (Value_identifier: 72) (Text_identifier: E)]\n[seq: CGIKQTSGAHGPPQF (Value_identifier: 26) (Text_identifier: C)]\n', '[seq: CITGSHGPQQGKAPF (Value_identifier: 76) (Text_identifier: A)]\n[seq: CITGSHGPQQGKAPF (Value_identifier: 28) (Text_identifier: A)]\n', '[seq: CTGSPGPHAQKQIGF (Value_identifier: 30) (Text_identifier: A)]\n[seq: CTGSPGPHAQKQIGF (Value_identifier: 80) (Text_identifier: A)]\n', '[seq: CPQHGGISTPKQGAF (Value_identifier: 32) (Text_identifier: A)]\n[seq: CPQHGGISTPKQGAF (Value_identifier: 84) (Text_identifier: C)]\n', '[seq: CGQPGTQIGSAKPHF (Value_identifier: 34) (Text_identifier: C)]\n[seq: CGQPGTQIGSAKPHF (Value_identifier: 88) (Text_identifier: A)]\n', '[seq: CQPQKGPASTIGHGF (Value_identifier: 92) (Text_identifier: C)]\n[seq: CQPQKGPASTIGHGF (Value_identifier: 36) (Text_identifier: A)]\n', '[seq: CKQGPSGPTKAQGIF (Value_identifier: 16) (Text_identifier: C)]\n[seq: CKQGPSGPTHAQGIF (Value_identifier: 96) (Text_identifier: A)]\n[seq: CKQGPSGPTHAQGIF (Value_identifier: 38) (Text_identifier: A)]\n', '[seq: CAPQQTPGSIKHGGF (Value_identifier: 40) (Text_identifier: A)]\n[seq: CAPQQTPGSIKHGGF (Value_identifier: 100) (Text_identifier: B)]\n', '[seq: CHPIQPKGTAGQGSF (Value_identifier: 104) (Text_identifier: B)]\n[seq: CHPIQPKGTAGQGSF (Value_identifier: 41) (Text_identifier: E)]\n', '[seq: CKIPGQPSQHGGATF (Value_identifier: 108) (Text_identifier: E)]\n', '[seq: CAQGQPKPGHTGISF (Value_identifier: 112) (Text_identifier: A)]\n', '[seq: CGGPTSQHKPAQGIF (Value_identifier: 116) (Text_identifier: A)]\n', '[seq: CPAGPKQITQSGGHF (Value_identifier: 120) (Text_identifier: C)]\n', '[seq: CGPPGQAHSGTQIKF (Value_identifier: 124) (Text_identifier: A)]\n', '[seq: CGHGAGPIQQKTPSF (Value_identifier: 128) (Text_identifier: C)]\n', '[seq: CIGPQAHQTGPKGSF (Value_identifier: 132) (Text_identifier: A)]\n', '[seq: CQHGPIKSGTGPAQF (Value_identifier: 136) (Text_identifier: B)]\n', '[seq: CKTGHSIGPQAPGQF (Value_identifier: 140) (Text_identifier: B)]\n', '[seq: CQTQPGKGIHSGAPF (Value_identifier: 144) (Text_identifier: E)]\n', '[seq: CSGQAPHPGKGQTIF (Value_identifier: 148) (Text_identifier: A)]\n', '[seq: CHKTGGPPSQAQGIF (Value_identifier: 152) (Text_identifier: A)]\n', '[seq: CQGSPIGQGATPKHF (Value_identifier: 156) (Text_identifier: C)]\n', '[seq: CGGQKSQTIPGPAHF (Value_identifier: 160) (Text_identifier: A)]\n', '[seq: CTQASHGPPQKGIGF (Value_identifier: 164) (Text_identifier: C)]\n', '[seq: CKSTGAQHGPPIGQF (Value_identifier: 168) (Text_identifier: A)]\n', '[seq: CSPQHAQGIGTPGKF (Value_identifier: 172) (Text_identifier: B)]\n', '[seq: CPKISTHQQPGAGGF (Value_identifier: 176) (Text_identifier: B)]\n', '[seq: CKHSGGPIAQQPGTF (Value_identifier: 180) (Text_identifier: E)]\n', '[seq: CSAPPQGGGTIHQKF (Value_identifier: 184) (Text_identifier: A)]\n', '[seq: CKTQSAIHGPQGPGF (Value_identifier: 188) (Text_identifier: A)]\n', '[seq: CHGSQTPGGPIQKAF (Value_identifier: 192) (Text_identifier: C)]\n', '[seq: CSGGQPGPAKTHIQF (Value_identifier: 196) (Text_identifier: A)]\n', '[seq: CAKGQGPQPIHSGTF (Value_identifier: 200) (Text_identifier: C)]\n', '[seq: CHGKGITPQAGSPQF (Value_identifier: 204) (Text_identifier: A)]\n', '[seq: CGQPQPTAHGIGSKF (Value_identifier: 208) (Text_identifier: B)]\n', '[seq: CPGKQTIAHQSGGPF (Value_identifier: 212) (Text_identifier: B)]\n', '[seq: CQTQHGIPGSKPAGF (Value_identifier: 216) (Text_identifier: E)]\n', '[seq: CQGIPPSGKAQHGTF (Value_identifier: 220) (Text_identifier: A)]\n', '[seq: CHGQGKQTIAPPGSF (Value_identifier: 224) (Text_identifier: A)]\n', '[seq: CAGHPGQSPIQTKGF (Value_identifier: 228) (Text_identifier: C)]\n', '[seq: CQPGATSKGPGQHIF (Value_identifier: 232) (Text_identifier: A)]\n', '[seq: CTHQGSAIKPPGGQF (Value_identifier: 236) (Text_identifier: C)]\n', '[seq: CGIKTGPQQPAHSGF (Value_identifier: 240) (Text_identifier: A)]\n', '[seq: CTHSPPGGGKAQQIF (Value_identifier: 244) (Text_identifier: B)]\n', '[seq: CGSQPPITKAHPQGF (Value_identifier: 8) (Text_identifier: D)]\n[seq: CGSQPPITKAHGQGF (Value_identifier: 248) (Text_identifier: B)]\n', '[seq: CPKGHQGGIQATSPF (Value_identifier: 252) (Text_identifier: E)]\n', '[seq: CAGQITGHQKPPGSF (Value_identifier: 256) (Text_identifier: A)]\n', '[seq: CSAPTIHQQGGPGKF (Value_identifier: 260) (Text_identifier: A)]\n', '[seq: CPQQKGGGHTASIPF (Value_identifier: 264) (Text_identifier: C)]\n', '[seq: CPQTSGAIHQKGPGF (Value_identifier: 268) (Text_identifier: A)]\n', '[seq: CQQKPSAIGHGGPTF (Value_identifier: 272) (Text_identifier: C)]\n', '[seq: CHQPAPIGTKQGSGF (Value_identifier: 276) (Text_identifier: A)]\n', '[seq: CIKPHQASGGGTPQF (Value_identifier: 280) (Text_identifier: B)]\n', '[seq: CQKPHQSGTIPGAGF (Value_identifier: 284) (Text_identifier: B)]\n', '[seq: CIQKPSHTGPGQAGF (Value_identifier: 288) (Text_identifier: E)]\n', '[seq: CGSAGQGPPHTQIKF (Value_identifier: 292) (Text_identifier: A)]\n', '[seq: CTQGGSGQPHIKPAF (Value_identifier: 296) (Text_identifier: A)]\n', '[seq: CAGHPPQGTKQGISF (Value_identifier: 300) (Text_identifier: C)]\n', '[seq: CIPSAQPQGHKGGTF (Value_identifier: 304) (Text_identifier: A)]\n', '[seq: CIPGQHAGPKGQTSF (Value_identifier: 308) (Text_identifier: C)]\n', '[seq: CAQQSTKGPHGIGPF (Value_identifier: 312) (Text_identifier: A)]\n', '[seq: CPPATGQHQSIGKGF (Value_identifier: 316) (Text_identifier: B)]\n', '[seq: CGGHIPKSPAQQTGF (Value_identifier: 320) (Text_identifier: B)]\n', '[seq: CIGPGKTPGHAQQSF (Value_identifier: 324) (Text_identifier: E)]\n', '[seq: CSQKPGTIHQGAGPF (Value_identifier: 328) (Text_identifier: A)]\n', '[seq: CAGPPKGQGQIHTSF (Value_identifier: 332) (Text_identifier: A)]\n', '[seq: CKHIQGPGSQGPTAF (Value_identifier: 336) (Text_identifier: C)]\n', '[seq: CSGQTGGPIKPHAQF (Value_identifier: 340) (Text_identifier: A)]\n', '[seq: CTGQGHQPGPISKAF (Value_identifier: 344) (Text_identifier: C)]\n', '[seq: CPGAKQIGTPSHQGF (Value_identifier: 348) (Text_identifier: A)]\n', '[seq: CGSPQPIKTHGAGQF (Value_identifier: 352) (Text_identifier: B)]\n', '[seq: CHQPGTPGKSGAQIF (Value_identifier: 356) (Text_identifier: B)]\n', '[seq: CIHQATGPQKPGSGF (Value_identifier: 360) (Text_identifier: E)]\n', '[seq: CQSKPGAGGHPTQIF (Value_identifier: 364) (Text_identifier: A)]\n', '[seq: CGQSPAGGKHQTPIF (Value_identifier: 368) (Text_identifier: A)]\n', '[seq: CTGPQQKHGAGSPIF (Value_identifier: 372) (Text_identifier: C)]\n', '[seq: CAQTSGKHGIQPPGF (Value_identifier: 376) (Text_identifier: A)]\n', '[seq: CKSIPAPHGGGQTQF (Value_identifier: 380) (Text_identifier: C)]\n', '[seq: CKTIGPQGSGQAHPF (Value_identifier: 384) (Text_identifier: A)]\n', '[seq: CQHQTAPKIPSGGGF (Value_identifier: 388) (Text_identifier: B)]\n', '[seq: CQKPPGTGGHQISAF (Value_identifier: 392) (Text_identifier: B)]\n', '[seq: CQGAIHSKGQPTGPF (Value_identifier: 396) (Text_identifier: E)]\n', '[seq: CGGTPQSQHAIPKGF (Value_identifier: 400) (Text_identifier: A)]\n', '[seq: CGKHQAPPTQGSGIF (Value_identifier: 400) (Text_identifier: A)]\n[seq: CGKHQAQPTQGSGIF (Value_identifier: 10) (Text_identifier: E)]\n']

        self.DB_dataframe = pd.DataFrame()
        self.DB_dataframe['seq'] = self.seq
        self.DB_dataframe['info'] = self.info
        self.DB_dataframe['results'] = self.results

class BlastTrueFile:
    def __init__(self):
        self.seq = ['CPTGGAQGKHIPQSF', 'CKASIPQGTHGGQPF', 'CPIQGHPASQGGKTF', 'CATGIHGQSQPKPGF', 'CPKTGQQSAHGGPIF', 'CPQPGGKIAQGHSTF', 'CPGISPQGAKTQHGF', 'CQPQHPKTGGGIASF', 'CGKSQGPQGPAHITF', 'CTGGPSIHPQAKQGF', 'CITHGAGPPSQGKQF', 'CPHQQGGIASTKGPF', 'CIGSQPGPHKTQGAF', 'CGKSPHATPQIGGQF', 'CTQSKIGQAGHPGPF', 'CGPASTHIQQPGGKF', 'CGIKQTSGAHGPPQF', 'CITGSHGPQQGKAPF', 'CTGSPGPHAQKQIGF', 'CPQHGGISTPKQGAF', 'CGQPGTQIGSAKPHF', 'CQPQKGPASTIGHGF', 'CKQGPSGPTHAQGIF', 'CAPQQTPGSIKHGGF', 'CHPIQPKGTAGQGSF', 'CKIPGQPSQHGGATF', 'CAQGQPKPGHTGISF', 'CGGPTSQHKPAQGIF', 'CPAGPKQITQSGGHF', 'CGPPGQAHSGTQIKF', 'CGHGAGPIQQKTPSF', 'CIGPQAHQTGPKGSF', 'CQHGPIKSGTGPAQF', 'CKTGHSIGPQAPGQF', 'CQTQPGKGIHSGAPF', 'CSGQAPHPGKGQTIF', 'CHKTGGPPSQAQGIF', 'CQGSPIGQGATPKHF', 'CGGQKSQTIPGPAHF', 'CTQASHGPPQKGIGF', 'CKSTGAQHGPPIGQF', 'CSPQHAQGIGTPGKF', 'CPKISTHQQPGAGGF', 'CKHSGGPIAQQPGTF', 'CSAPPQGGGTIHQKF', 'CKTQSAIHGPQGPGF', 'CHGSQTPGGPIQKAF', 'CSGGQPGPAKTHIQF', 'CAKGQGPQPIHSGTF', 'CHGKGITPQAGSPQF', 'CGQPQPTAHGIGSKF', 'CPGKQTIAHQSGGPF', 'CQTQHGIPGSKPAGF', 'CQGIPPSGKAQHGTF', 'CHGQGKQTIAPPGSF', 'CAGHPGQSPIQTKGF', 'CQPGATSKGPGQHIF', 'CTHQGSAIKPPGGQF', 'CGIKTGPQQPAHSGF', 'CTHSPPGGGKAQQIF', 'CGSQPPITKAHGQGF', 'CPKGHQGGIQATSPF', 'CAGQITGHQKPPGSF', 'CSAPTIHQQGGPGKF', 'CPQQKGGGHTASIPF', 'CPQTSGAIHQKGPGF', 'CQQKPSAIGHGGPTF', 'CHQPAPIGTKQGSGF', 'CIKPHQASGGGTPQF', 'CQKPHQSGTIPGAGF', 'CIQKPSHTGPGQAGF', 'CGSAGQGPPHTQIKF', 'CTQGGSGQPHIKPAF', 'CAGHPPQGTKQGISF', 'CIPSAQPQGHKGGTF', 'CIPGQHAGPKGQTSF', 'CAQQSTKGPHGIGPF', 'CPPATGQHQSIGKGF', 'CGGHIPKSPAQQTGF', 'CIGPGKTPGHAQQSF', 'CSQKPGTIHQGAGPF', 'CAGPPKGQGQIHTSF', 'CKHIQGPGSQGPTAF', 'CSGQTGGPIKPHAQF', 'CTGQGHQPGPISKAF', 'CPGAKQIGTPSHQGF', 'CGSPQPIKTHGAGQF', 'CHQPGTPGKSGAQIF', 'CIHQATGPQKPGSGF', 'CQSKPGAGGHPTQIF', 'CGQSPAGGKHQTPIF', 'CTGPQQKHGAGSPIF', 'CAQTSGKHGIQPPGF', 'CKSIPAPHGGGQTQF', 'CKTIGPQGSGQAHPF', 'CQHQTAPKIPSGGGF', 'CQKPPGTGGHQISAF', 'CQGAIHSKGQPTGPF', 'CGGTPQSQHAIPKGF', 'CGKHQAPPTQGSGIF']
        self.info = [62, 6, 83, 22, 73, 43, 7, 92, 9, 77, 30, 68, 29, 52, 69, 43, 25, 11, 14, 42, 46, 69, 48, 19, 91, 55, 51, 34, 85, 34, 64, 84, 66, 73, 76, 72, 10, 20, 60, 67, 71, 30, 11, 46, 73, 23, 6, 45, 58, 12, 35, 48, 60, 38, 42, 35, 3, 77, 19, 3, 20, 48, 63, 1, 95, 58, 7, 53, 74, 84, 75, 46, 55, 86, 66, 24, 28, 24, 49, 56, 31, 95, 49, 58, 53, 61, 59, 98, 47, 20, 17, 28, 5, 6, 92, 38, 50, 50, 43, 6]
        self.results = ['[seq: CPTGGAQGKHIPQSF identifier:(Value_identifier:8)(Text_identifier:A)]\n[seq: CPTAGAQGKHIPQSF identifier:(Value_identifier:8)(Text_identifier:A)]\n[seq: CPPGGSQGHKITAQF identifier:(Value_identifier:43)(Text_identifier:B)]\n[seq: CPSGPQHGKTIAQGF identifier:(Value_identifier:12)(Text_identifier:B)]\n[seq: CPISGHQGKTAPGQF identifier:(Value_identifier:41)(Text_identifier:D)]\n', '[seq: CKASIPQGTHGGQPF identifier:(Value_identifier:12)(Text_identifier:C)]\n[seq: CKASIPQGTHGGQPF identifier:(Value_identifier:10)(Text_identifier:C)]\n[seq: CTSPQPQGAHGGIKF identifier:(Value_identifier:45)(Text_identifier:C)]\n[seq: CGQSIPAGPHGTKQF identifier:(Value_identifier:85)(Text_identifier:D)]\n', '[seq: CPIQGHPASQGGKTF identifier:(Value_identifier:12)(Text_identifier:A)]\n[seq: CPIQGHPASQGGKTF identifier:(Value_identifier:16)(Text_identifier:A)]\n[seq: CKIPGQPSQHGGATF identifier:(Value_identifier:108)(Text_identifier:E)]\n[seq: CQIQGHPGS identifier:(Value_identifier:55)(Text_identifier:A)]\n', '[seq: CATGIHGQSQPKPGF identifier:(Value_identifier:14)(Text_identifier:A)]\n[seq: CATGIHGQSQPKPGF identifier:(Value_identifier:20)(Text_identifier:C)]\n[seq: CSKGTHGIGQPAPQF identifier:(Value_identifier:18)(Text_identifier:C)]\n', '[seq: CPKTGQQSAHGGPIF identifier:(Value_identifier:24)(Text_identifier:A)]\n[seq: CPKTGQQSAHGGPIF identifier:(Value_identifier:16)(Text_identifier:A)]\n', '[seq: CPQPGGKIAQGHSTF identifier:(Value_identifier:28)(Text_identifier:B)]\n[seq: CPQPGGKIAQGHSTF identifier:(Value_identifier:18)(Text_identifier:C)]\n[seq: CPSTQGKPAQGHGIF identifier:(Value_identifier:5)(Text_identifier:B)]\n', '[seq: CPGISPQGAKTQHGF identifier:(Value_identifier:32)(Text_identifier:B)]\n[seq: CPGISPQGAKTQHGF identifier:(Value_identifier:20)(Text_identifier:A)]\n', '[seq: CQPQHPKTGGGIASF identifier:(Value_identifier:22)(Text_identifier:A)]\n[seq: CQPQHPKTGGGIASF identifier:(Value_identifier:36)(Text_identifier:E)]\n[seq: CGPHQPTQGGAIKSF identifier:(Value_identifier:70)(Text_identifier:A)]\n', '[seq: CGKSQGPQGPAHITF identifier:(Value_identifier:24)(Text_identifier:A)]\n[seq: CGKSQGPQGPAHITF identifier:(Value_identifier:40)(Text_identifier:A)]\n[seq: CGIKTGPQQPAHSGF identifier:(Value_identifier:240)(Text_identifier:A)]\n[seq: KSQGPQGIPHAT identifier:(Value_identifier:75)(Text_identifier:D)]\n', '[seq: CTGGPSIHPQAKQGF identifier:(Value_identifier:44)(Text_identifier:A)]\n[seq: CAQTPSIHPGQKGGF identifier:(Value_identifier:21)(Text_identifier:C)]\n[seq: CTIGPAGHKPSQQGF identifier:(Value_identifier:44)(Text_identifier:D)]\n[seq: CTGSPGPHAQKQIGF identifier:(Value_identifier:80)(Text_identifier:A)]\n[seq: CTGSPGPHAQKQIGF identifier:(Value_identifier:30)(Text_identifier:A)]\n[seq: CQQGPSIHP identifier:(Value_identifier:32)(Text_identifier:E)]\n[seq: CTKGPGASPQHQIGF identifier:(Value_identifier:71)(Text_identifier:B)]\n[seq: GTPQIHPQSK identifier:(Value_identifier:7)(Text_identifier:B)]\n', '[seq: CITHGAGPPSQGKQF identifier:(Value_identifier:48)(Text_identifier:C)]\n[seq: THGSGPPIQG identifier:(Value_identifier:49)(Text_identifier:A)]\n[seq: CIHQGAGPTSKPGQF identifier:(Value_identifier:19)(Text_identifier:E)]\n[seq: CITQGGGPSHKPAQF identifier:(Value_identifier:69)(Text_identifier:B)]\n[seq: CATKGIQPPGSGHQF identifier:(Value_identifier:46)(Text_identifier:A)]\n[seq: CITKAQGPSGQGPHF identifier:(Value_identifier:80)(Text_identifier:D)]\n', '[seq: CPHQQGGIASTKGPF identifier:(Value_identifier:52)(Text_identifier:A)]\n[seq: CPHGPGQIATQKGSF identifier:(Value_identifier:16)(Text_identifier:A)]\n[seq: CPHSKATIGGQQGPF identifier:(Value_identifier:10)(Text_identifier:A)]\n[seq: CPTKQGSIQAHGGPF identifier:(Value_identifier:91)(Text_identifier:B)]\n[seq: CPQTQGGGSAIKHPF identifier:(Value_identifier:22)(Text_identifier:E)]\n[seq: PHQQGGITA identifier:(Value_identifier:26)(Text_identifier:E)]\n', '[seq: CIGSQPGPHKTQGAF identifier:(Value_identifier:56)(Text_identifier:C)]\n[seq: CIGAQPGPGSTQKHF identifier:(Value_identifier:70)(Text_identifier:B)]\n[seq: CSGGQPGPAKTHIQF identifier:(Value_identifier:196)(Text_identifier:A)]\n', '[seq: CGKSPHATPQIGGQF identifier:(Value_identifier:60)(Text_identifier:A)]\n[seq: CQKTPHQGPSAGGIF identifier:(Value_identifier:71)(Text_identifier:D)]\n[seq: CGPTPQQSKHIGGAF identifier:(Value_identifier:93)(Text_identifier:A)]\n', '[seq: CTQSKIGQAGHPGPF identifier:(Value_identifier:64)(Text_identifier:B)]\n[seq: CTKS--GQAQHPGP identifier:(Value_identifier:23)(Text_identifier:D)]\n[seq: CTKHPIGQGGAPSQF identifier:(Value_identifier:9)(Text_identifier:A)]\n[seq: IGQSGHPQP identifier:(Value_identifier:58)(Text_identifier:E)]\n', '[seq: CGPASTHIQQPGGKF identifier:(Value_identifier:68)(Text_identifier:B)]\n[seq: CGATKIHPQQSGGPF identifier:(Value_identifier:73)(Text_identifier:A)]\n', '[seq: CGIKQTSGAHGPPQF identifier:(Value_identifier:26)(Text_identifier:C)]\n[seq: CGIKQTSGAHGPPQF identifier:(Value_identifier:72)(Text_identifier:E)]\n[seq: CQATQSGGIHGPPKF identifier:(Value_identifier:35)(Text_identifier:C)]\n[seq: CIQKQTSGPHGGPAF identifier:(Value_identifier:42)(Text_identifier:B)]\n[seq: CGIKSTQPPHGGAQF identifier:(Value_identifier:44)(Text_identifier:C)]\n[seq: CTIKPQAGQHGPSGF identifier:(Value_identifier:93)(Text_identifier:B)]\n', '[seq: CITGSHGPQQGKAPF identifier:(Value_identifier:28)(Text_identifier:A)]\n[seq: CITGSHGPQQGKAPF identifier:(Value_identifier:76)(Text_identifier:A)]\n[seq: CIQGPHGSQGAKTPF identifier:(Value_identifier:12)(Text_identifier:A)]\n', '[seq: CTGSPGPHAQKQIGF identifier:(Value_identifier:80)(Text_identifier:A)]\n[seq: CTGSPGPHAQKQIGF identifier:(Value_identifier:30)(Text_identifier:A)]\n[seq: CKGQGSPHAQPTIGF identifier:(Value_identifier:3)(Text_identifier:D)]\n[seq: CTKGPGASPQHQIGF identifier:(Value_identifier:71)(Text_identifier:B)]\n[seq: CHIGPGPQATKQSGF identifier:(Value_identifier:38)(Text_identifier:C)]\n[seq: CTGIQKPHASGQPGF identifier:(Value_identifier:61)(Text_identifier:B)]\n[seq: CTGGPSIHPQAKQGF identifier:(Value_identifier:44)(Text_identifier:A)]\n[seq: CPGSKIPHATGQQGF identifier:(Value_identifier:67)(Text_identifier:B)]\n', '[seq: CPQHGGISTPKQGAF identifier:(Value_identifier:84)(Text_identifier:C)]\n[seq: CPQHGGISTPKQGAF identifier:(Value_identifier:32)(Text_identifier:A)]\n[seq: CQPSGGTAIPKQGHF identifier:(Value_identifier:74)(Text_identifier:B)]\n', '[seq: CGQPGTQIGSAKPHF identifier:(Value_identifier:88)(Text_identifier:A)]\n[seq: CGQPGTQIGSAKPHF identifier:(Value_identifier:34)(Text_identifier:C)]\n[seq: CGKSGTQQAGPIPHF identifier:(Value_identifier:80)(Text_identifier:A)]\n', '[seq: CQPQKGPASTIGHGF identifier:(Value_identifier:36)(Text_identifier:A)]\n[seq: CQPQKGPASTIGHGF identifier:(Value_identifier:92)(Text_identifier:C)]\n[seq: CQGKTQPAGSIGHPF identifier:(Value_identifier:9)(Text_identifier:B)]\n[seq: CQPAHGSGPTIKQGF identifier:(Value_identifier:34)(Text_identifier:B)]\n[seq: CQPGKGPSQGIATHF identifier:(Value_identifier:49)(Text_identifier:D)]\n', '[seq: CKQGPSGPTHAQGIF identifier:(Value_identifier:38)(Text_identifier:A)]\n[seq: CKQGPSGPTHAQGIF identifier:(Value_identifier:96)(Text_identifier:A)]\n[seq: CKQGPSGPTKAQGIF identifier:(Value_identifier:16)(Text_identifier:C)]\n[seq: CKQGHSGPTGAQPIF identifier:(Value_identifier:18)(Text_identifier:C)]\n[seq: CGKGPSTPQAQHGIF identifier:(Value_identifier:86)(Text_identifier:E)]\n[seq: CQIGPGKPSHQAGTF identifier:(Value_identifier:32)(Text_identifier:B)]\n[seq: CAQGPHGPT identifier:(Value_identifier:7)(Text_identifier:A)]\n[seq: CHKQPGGPTQAIGSF identifier:(Value_identifier:21)(Text_identifier:D)]\n', '[seq: CAPQQTPGSIKHGGF identifier:(Value_identifier:100)(Text_identifier:B)]\n[seq: CAPQQTPGSIKHGGF identifier:(Value_identifier:40)(Text_identifier:A)]\n[seq: CAPQQSPTIHGKGGF identifier:(Value_identifier:69)(Text_identifier:E)]\n[seq: CSAQQTPGGHKIPGF identifier:(Value_identifier:68)(Text_identifier:D)]\n', '[seq: CHPIQPKGTAGQGSF identifier:(Value_identifier:41)(Text_identifier:E)]\n[seq: CHPIQPKGTAGQGSF identifier:(Value_identifier:104)(Text_identifier:B)]\n[seq: HPPQSKGTAGQG identifier:(Value_identifier:66)(Text_identifier:D)]\n', '[seq: CKIPGQPSQHGGATF identifier:(Value_identifier:108)(Text_identifier:E)]\n[seq: CASIGPPQQHGGKTF identifier:(Value_identifier:68)(Text_identifier:A)]\n[seq: CPIQGHPASQGGKTF identifier:(Value_identifier:12)(Text_identifier:A)]\n[seq: CPIQGHPASQGGKTF identifier:(Value_identifier:16)(Text_identifier:A)]\n[seq: PGQPSQIGG identifier:(Value_identifier:73)(Text_identifier:A)]\n', '[seq: CAQGQPKPGHTGISF identifier:(Value_identifier:112)(Text_identifier:A)]\n[seq: CAKGQPTPGQGHISF identifier:(Value_identifier:99)(Text_identifier:A)]\n[seq: GQTKPGHAGIS identifier:(Value_identifier:98)(Text_identifier:D)]\n', '[seq: CGGPTSQHKPAQGIF identifier:(Value_identifier:116)(Text_identifier:A)]\n[seq: CTGPKAQHIPSQGGF identifier:(Value_identifier:60)(Text_identifier:B)]\n[seq: CGGKHTSPAPQQGIF identifier:(Value_identifier:86)(Text_identifier:E)]\n', '[seq: CPAGPKQITQSGGHF identifier:(Value_identifier:120)(Text_identifier:C)]\n[seq: CPGTPSKIGQQAGHF identifier:(Value_identifier:77)(Text_identifier:A)]\n[seq: PAGPKQITSQG identifier:(Value_identifier:24)(Text_identifier:B)]\n[seq: CQGGPTQAIKSGPHF identifier:(Value_identifier:99)(Text_identifier:C)]\n[seq: CPHGPGQIATQKGSF identifier:(Value_identifier:16)(Text_identifier:A)]\n', '[seq: CGPPGQAHSGTQIKF identifier:(Value_identifier:124)(Text_identifier:A)]\n[seq: CGSAGQGPPHTQIKF identifier:(Value_identifier:292)(Text_identifier:A)]\n', '[seq: CGHGAGPIQQKTPSF identifier:(Value_identifier:128)(Text_identifier:C)]\n[seq: CGGHAGPIQQSTKPF identifier:(Value_identifier:75)(Text_identifier:A)]\n[seq: CGHSAIPTQQGGPKF identifier:(Value_identifier:8)(Text_identifier:D)]\n', '[seq: CIGPQAHQTGPKGSF identifier:(Value_identifier:132)(Text_identifier:A)]\n[seq: CIGPPGHQSATKGQF identifier:(Value_identifier:32)(Text_identifier:D)]\n[seq: GPQSHQATPK identifier:(Value_identifier:63)(Text_identifier:C)]\n', '[seq: CQHGPIKSGTGPAQF identifier:(Value_identifier:136)(Text_identifier:B)]\n[seq: CQHGASKTGIPPQGF identifier:(Value_identifier:95)(Text_identifier:C)]\n', '[seq: CKTGHSIGPQAPGQF identifier:(Value_identifier:140)(Text_identifier:B)]\n[seq: CAHGGKTGPQIPSQF identifier:(Value_identifier:55)(Text_identifier:B)]\n', '[seq: CQTQPGKGIHSGAPF identifier:(Value_identifier:144)(Text_identifier:E)]\n[seq: CQTPPGKGQHAIGSF identifier:(Value_identifier:50)(Text_identifier:D)]\n', '[seq: CSGQAPHPGKGQTIF identifier:(Value_identifier:148)(Text_identifier:A)]\n[seq: CTGQKPHPAGSQIGF identifier:(Value_identifier:77)(Text_identifier:B)]\n[seq: CGGPQSHPKTGQAIF identifier:(Value_identifier:32)(Text_identifier:E)]\n', '[seq: CHKTGGPPSQAQGIF identifier:(Value_identifier:152)(Text_identifier:A)]\n[seq: CHKQPGGPTQAIGSF identifier:(Value_identifier:21)(Text_identifier:D)]\n[seq: CGKHQAPPTQGSGIF identifier:(Value_identifier:400)(Text_identifier:A)]\n[seq: CHGTPGPASQQGKIF identifier:(Value_identifier:40)(Text_identifier:D)]\n[seq: CPSTQGKPAQGHGIF identifier:(Value_identifier:5)(Text_identifier:B)]\n', '[seq: CQGSPIGQGATPKHF identifier:(Value_identifier:156)(Text_identifier:C)]\n[seq: CTKHPIGQGGAPSQF identifier:(Value_identifier:9)(Text_identifier:A)]\n[seq: CSGIPAGQQKGPTHF identifier:(Value_identifier:26)(Text_identifier:A)]\n', '[seq: CGGQKSQTIPGPAHF identifier:(Value_identifier:160)(Text_identifier:A)]\n[seq: CGGAQTQPIPGHSKF identifier:(Value_identifier:45)(Text_identifier:B)]\n', '[seq: CTQASHGPPQKGIGF identifier:(Value_identifier:164)(Text_identifier:C)]\n[seq: CKQASGGHPQTGIPF identifier:(Value_identifier:72)(Text_identifier:A)]\n[seq: CTIKHQGPPQGGASF identifier:(Value_identifier:24)(Text_identifier:B)]\n', '[seq: CKSTGAQHGPPIGQF identifier:(Value_identifier:168)(Text_identifier:A)]\n[seq: CKGTIHQQGPPAGSF identifier:(Value_identifier:91)(Text_identifier:D)]\n[seq: CKQTGHISAPPGGQF identifier:(Value_identifier:29)(Text_identifier:C)]\n[seq: AQHGPKIGQ identifier:(Value_identifier:18)(Text_identifier:B)]\n', '[seq: CSPQHAQGIGTPGKF identifier:(Value_identifier:172)(Text_identifier:B)]\n', '[seq: CPKISTHQQPGAGGF identifier:(Value_identifier:176)(Text_identifier:B)]\n[seq: CPGIAKHQTQPGSG identifier:(Value_identifier:14)(Text_identifier:A)]\n', '[seq: CKHSGGPIAQQPGTF identifier:(Value_identifier:180)(Text_identifier:E)]\n', '[seq: CSAPPQGGGTIHQKF identifier:(Value_identifier:184)(Text_identifier:A)]\n[seq: CAGPPKGQGQIHTSF identifier:(Value_identifier:332)(Text_identifier:A)]\n[seq: CSGQPAGGTKIHQPF identifier:(Value_identifier:85)(Text_identifier:C)]\n[seq: PPQGTGAIHQ identifier:(Value_identifier:13)(Text_identifier:D)]\n', '[seq: CKTQSAIHGPQGPGF identifier:(Value_identifier:188)(Text_identifier:A)]\n', '[seq: CHGSQTPGGPIQKAF identifier:(Value_identifier:192)(Text_identifier:C)]\n', '[seq: CSGGQPGPAKTHIQF identifier:(Value_identifier:196)(Text_identifier:A)]\n[seq: CAKGQPTPGQGHISF identifier:(Value_identifier:99)(Text_identifier:A)]\n[seq: CAGGQTGPSPHQIKF identifier:(Value_identifier:49)(Text_identifier:C)]\n[seq: CIGSQPGPHKTQGAF identifier:(Value_identifier:56)(Text_identifier:C)]\n[seq: CIGAQPGPGSTQKHF identifier:(Value_identifier:70)(Text_identifier:B)]\n[seq: CSGQTGGPIKPHAQF identifier:(Value_identifier:340)(Text_identifier:A)]\n[seq: CSGQGPGP-KAHIQ identifier:(Value_identifier:77)(Text_identifier:E)]\n', '[seq: CAKGQGPQPIHSGTF identifier:(Value_identifier:200)(Text_identifier:C)]\n[seq: CHSGQKPTPIQAGGF identifier:(Value_identifier:57)(Text_identifier:C)]\n', '[seq: CHGKGITPQAGSPQF identifier:(Value_identifier:204)(Text_identifier:A)]\n[seq: CHGQKAGPQIGSPTF identifier:(Value_identifier:91)(Text_identifier:D)]\n[seq: CHGKGIAPPQGQTSF identifier:(Value_identifier:60)(Text_identifier:C)]\n[seq: CHTKGSIQGPGAPQF identifier:(Value_identifier:6)(Text_identifier:A)]\n', '[seq: CGQPQPTAHGIGSKF identifier:(Value_identifier:208)(Text_identifier:B)]\n[seq: CGQPAPHKTGIGSQF identifier:(Value_identifier:3)(Text_identifier:E)]\n[seq: CGTPAPSGHQIQGKF identifier:(Value_identifier:73)(Text_identifier:B)]\n[seq: CTQIQPKPHGSGAGF identifier:(Value_identifier:27)(Text_identifier:D)]\n', '[seq: CPGKQTIAHQSGGPF identifier:(Value_identifier:212)(Text_identifier:B)]\n[seq: CPGQHPITAQKGGSF identifier:(Value_identifier:97)(Text_identifier:E)]\n', '[seq: CQTQHGIPGSKPAGF identifier:(Value_identifier:216)(Text_identifier:E)]\n[seq: CTQQHGIPGSPGAKF identifier:(Value_identifier:53)(Text_identifier:B)]\n[seq: CQSPHGKPGTQAIGF identifier:(Value_identifier:80)(Text_identifier:A)]\n[seq: CKPAHTIPGQQGSGF identifier:(Value_identifier:89)(Text_identifier:B)]\n', '[seq: CQGIPPSGKAQHGTF identifier:(Value_identifier:220)(Text_identifier:A)]\n[seq: CQHPPISGKGQTGAF identifier:(Value_identifier:57)(Text_identifier:B)]\n', '[seq: CHGQGKQTIAPPGSF identifier:(Value_identifier:224)(Text_identifier:A)]\n[seq: CHGQAKQPSGTPGIF identifier:(Value_identifier:38)(Text_identifier:D)]\n[seq: CQSKGGGTIAPPHQF identifier:(Value_identifier:46)(Text_identifier:E)]\n', '[seq: CAGHPGQSPIQTKGF identifier:(Value_identifier:228)(Text_identifier:C)]\n[seq: CGAIPGHQPTQSKGF identifier:(Value_identifier:84)(Text_identifier:C)]\n[seq: CGGHIPKSPAQQTGF identifier:(Value_identifier:320)(Text_identifier:B)]\n[seq: CAGQPSGTPIQKGHF identifier:(Value_identifier:64)(Text_identifier:C)]\n', '[seq: CQPGATSKGPGQHIF identifier:(Value_identifier:232)(Text_identifier:A)]\n[seq: CQPGAQKIGPSTHGF identifier:(Value_identifier:70)(Text_identifier:B)]\n[seq: CQPTPGAQGSGKHIF identifier:(Value_identifier:51)(Text_identifier:A)]\n[seq: CQAGPKGQGPSTHIF identifier:(Value_identifier:67)(Text_identifier:E)]\n', '[seq: CTHQGSAIKPPGGQF identifier:(Value_identifier:236)(Text_identifier:C)]\n[seq: CTIQGAHQKPPGSGF identifier:(Value_identifier:33)(Text_identifier:B)]\n[seq: CKQTGHISAPPGGQF identifier:(Value_identifier:29)(Text_identifier:C)]\n[seq: CTHGGPQISAPGQKF identifier:(Value_identifier:93)(Text_identifier:E)]\n[seq: CTKQGGPIQHPSGAF identifier:(Value_identifier:59)(Text_identifier:B)]\n[seq: CAHQPSGKQPIGGTF identifier:(Value_identifier:17)(Text_identifier:A)]\n', '[seq: CGIKTGPQQPAHSGF identifier:(Value_identifier:240)(Text_identifier:A)]\n[seq: CGKSQGPQGPAHITF identifier:(Value_identifier:24)(Text_identifier:A)]\n[seq: CGKSQGPQGPAHITF identifier:(Value_identifier:40)(Text_identifier:A)]\n[seq: CAISHGPQQPGTGKF identifier:(Value_identifier:53)(Text_identifier:B)]\n', '[seq: CTHSPPGGGKAQQIF identifier:(Value_identifier:244)(Text_identifier:B)]\n[seq: CHQTPPGGGQSKIAF identifier:(Value_identifier:24)(Text_identifier:B)]\n[seq: CTH-PPGGASGQKI identifier:(Value_identifier:61)(Text_identifier:E)]\n[seq: HTPPGGKGSQQF identifier:(Value_identifier:56)(Text_identifier:A)]\n', '[seq: CGSQPPITKAHGQGF identifier:(Value_identifier:248)(Text_identifier:B)]\n[seq: CGSQPPITKAHPQGF identifier:(Value_identifier:8)(Text_identifier:D)]\n[seq: CGAQPPSQGTHIKGF identifier:(Value_identifier:39)(Text_identifier:E)]\n[seq: CAIQQPTGKSHGPGF identifier:(Value_identifier:30)(Text_identifier:D)]\n[seq: CKASGPITPGHGQQF identifier:(Value_identifier:84)(Text_identifier:A)]\n', '[seq: CPKGHQGGIQATSPF identifier:(Value_identifier:252)(Text_identifier:E)]\n[seq: CPIGQHGGKQASTPF identifier:(Value_identifier:81)(Text_identifier:B)]\n[seq: CTPGHKGGAQSIQPF identifier:(Value_identifier:80)(Text_identifier:B)]\n', '[seq: CAGQITGHQKPPGSF identifier:(Value_identifier:256)(Text_identifier:A)]\n[seq: CSGGITGKHQQPP identifier:(Value_identifier:70)(Text_identifier:E)]\n[seq: HQKPPGS identifier:(Value_identifier:33)(Text_identifier:B)]\n[seq: CAQHKIGSQTPPGGF identifier:(Value_identifier:67)(Text_identifier:E)]\n', '[seq: CSAPTIHQQGGPGKF identifier:(Value_identifier:260)(Text_identifier:A)]\n[seq: CSPGQIHGQAGPTKF identifier:(Value_identifier:55)(Text_identifier:A)]\n', '[seq: CPQQKGGGHTASIPF identifier:(Value_identifier:264)(Text_identifier:C)]\n[seq: CPQTQGGGSAIKHPF identifier:(Value_identifier:22)(Text_identifier:E)]\n', '[seq: CPQTSGAIHQKGPGF identifier:(Value_identifier:268)(Text_identifier:A)]\n', '[seq: CQQKPSAIGHGGPTF identifier:(Value_identifier:272)(Text_identifier:C)]\n[seq: CQKTPSHPGQGGAIF identifier:(Value_identifier:74)(Text_identifier:B)]\n[seq: CIQKQTSGPHGGPAF identifier:(Value_identifier:42)(Text_identifier:B)]\n[seq: CHQKPQSPGTGGIAF identifier:(Value_identifier:9)(Text_identifier:D)]\n', '[seq: CHQPAPIGTKQGSGF identifier:(Value_identifier:276)(Text_identifier:A)]\n[seq: CSQPGQIATPHGKGF identifier:(Value_identifier:4)(Text_identifier:C)]\n', '[seq: CIKPHQASGGGTPQF identifier:(Value_identifier:280)(Text_identifier:B)]\n[seq: KASGGGTPQF identifier:(Value_identifier:45)(Text_identifier:A)]\n[seq: ISPHGAQGG-TPQF identifier:(Value_identifier:51)(Text_identifier:B)]\n', '[seq: CQKPHQSGTIPGAGF identifier:(Value_identifier:284)(Text_identifier:B)]\n[seq: CKIPHQAGSPQGTGF identifier:(Value_identifier:54)(Text_identifier:A)]\n[seq: CKQPHQTPIGAGSGF identifier:(Value_identifier:15)(Text_identifier:C)]\n[seq: CQAPHKPITGQGSGF identifier:(Value_identifier:46)(Text_identifier:E)]\n', '[seq: CIQKPSHTGPGQAGF identifier:(Value_identifier:288)(Text_identifier:E)]\n[seq: CSGAPTHIKPGQQGF identifier:(Value_identifier:38)(Text_identifier:B)]\n[seq: KPAHTIPGQQG identifier:(Value_identifier:89)(Text_identifier:B)]\n[seq: CIQPPAHQGSGGKTF identifier:(Value_identifier:92)(Text_identifier:A)]\n', '[seq: CGSAGQGPPHTQIKF identifier:(Value_identifier:292)(Text_identifier:A)]\n[seq: SAGQGPPHT identifier:(Value_identifier:5)(Text_identifier:B)]\n[seq: CGPPGQAHSGTQIKF identifier:(Value_identifier:124)(Text_identifier:A)]\n', '[seq: CTQGGSGQPHIKPAF identifier:(Value_identifier:296)(Text_identifier:A)]\n[seq: GSKGQPHIQPA identifier:(Value_identifier:57)(Text_identifier:D)]\n[seq: CTQAGGSQHPIKPGF identifier:(Value_identifier:12)(Text_identifier:D)]\n[seq: TQGGSGKIH-QPAF identifier:(Value_identifier:9)(Text_identifier:B)]\n', '[seq: CAGHPPQGTKQGISF identifier:(Value_identifier:300)(Text_identifier:C)]\n[seq: CAGQPPQGHKGSITF identifier:(Value_identifier:85)(Text_identifier:C)]\n[seq: CSGKPPQGT identifier:(Value_identifier:13)(Text_identifier:D)]\n', '[seq: CIPSAQPQGHKGGTF identifier:(Value_identifier:304)(Text_identifier:A)]\n[seq: CIPQTGPSGHKGAQF identifier:(Value_identifier:18)(Text_identifier:D)]\n', '[seq: CIPGQHAGPKGQTSF identifier:(Value_identifier:308)(Text_identifier:C)]\n', '[seq: CAQQSTKGPHGIGPF identifier:(Value_identifier:312)(Text_identifier:A)]\n[seq: CIQKQTSGPHG identifier:(Value_identifier:42)(Text_identifier:B)]\n', '[seq: CPPATGQHQSIGKGF identifier:(Value_identifier:316)(Text_identifier:B)]\n', '[seq: CGGHIPKSPAQQTGF identifier:(Value_identifier:320)(Text_identifier:B)]\n[seq: CGGHPPTQSIKQAGF identifier:(Value_identifier:86)(Text_identifier:B)]\n[seq: CGGHGKQAPSQITPF identifier:(Value_identifier:28)(Text_identifier:D)]\n[seq: CAGHPGQSPIQTKGF identifier:(Value_identifier:228)(Text_identifier:C)]\n', '[seq: CIGPGKTPGHAQQSF identifier:(Value_identifier:324)(Text_identifier:E)]\n[seq: CKGITSGPGHAQQPF identifier:(Value_identifier:45)(Text_identifier:C)]\n[seq: CITPGGKSAHPQQGF identifier:(Value_identifier:81)(Text_identifier:D)]\n[seq: CPGIAQKPGHGSQTF identifier:(Value_identifier:54)(Text_identifier:B)]\n', '[seq: CSQKPGTIHQGAGPF identifier:(Value_identifier:328)(Text_identifier:A)]\n[seq: CQAIPSGTHQGKGPF identifier:(Value_identifier:87)(Text_identifier:D)]\n[seq: CSKGPGQQHATIGPF identifier:(Value_identifier:59)(Text_identifier:E)]\n[seq: CKQAIGPQHTGSGPF identifier:(Value_identifier:86)(Text_identifier:C)]\n', '[seq: CAGPPKGQGQIHTSF identifier:(Value_identifier:332)(Text_identifier:A)]\n[seq: CSAPPQGGGTIHQKF identifier:(Value_identifier:184)(Text_identifier:A)]\n[seq: CSPPGKGQIQAHTGF identifier:(Value_identifier:15)(Text_identifier:B)]\n[seq: CIGPP-GQGQAKTS identifier:(Value_identifier:18)(Text_identifier:C)]\n[seq: CITPAKGQGSPHQGF identifier:(Value_identifier:99)(Text_identifier:E)]\n', '[seq: CKHIQGPGSQGPTAF identifier:(Value_identifier:336)(Text_identifier:C)]\n[seq: CKHIASPQQGGPTGF identifier:(Value_identifier:74)(Text_identifier:D)]\n[seq: HIQKPGTQSPGA identifier:(Value_identifier:65)(Text_identifier:A)]\n[seq: CQHAKQPGIGGPSTF identifier:(Value_identifier:54)(Text_identifier:B)]\n', '[seq: CSGQTGGPIKPHAQF identifier:(Value_identifier:340)(Text_identifier:A)]\n[seq: CSGGQPGPAKTHIQF identifier:(Value_identifier:196)(Text_identifier:A)]\n[seq: CTGHIGGPQQPSKAF identifier:(Value_identifier:67)(Text_identifier:D)]\n[seq: CSGAQGGHPKPTIQF identifier:(Value_identifier:74)(Text_identifier:C)]\n', '[seq: CTGQGHQPGPISKAF identifier:(Value_identifier:344)(Text_identifier:C)]\n[seq: CTGQAHQPSPGIKGF identifier:(Value_identifier:60)(Text_identifier:B)]\n[seq: CQGGGPQTAPISKHF identifier:(Value_identifier:36)(Text_identifier:B)]\n', '[seq: CPGAKQIGTPSHQGF identifier:(Value_identifier:348)(Text_identifier:A)]\n[seq: CAGTHQIGPPSKQGF identifier:(Value_identifier:8)(Text_identifier:D)]\n', '[seq: CGSPQPIKTHGAGQF identifier:(Value_identifier:352)(Text_identifier:B)]\n[seq: GGPQPIQAHG identifier:(Value_identifier:57)(Text_identifier:B)]\n[seq: CTSPQPQGAHGGIKF identifier:(Value_identifier:45)(Text_identifier:C)]\n', '[seq: CHQPGTPGKSGAQIF identifier:(Value_identifier:356)(Text_identifier:B)]\n[seq: CQQPGIPGKGASTHF identifier:(Value_identifier:46)(Text_identifier:C)]\n[seq: CHQIGQPGAPGKTSF identifier:(Value_identifier:19)(Text_identifier:E)]\n', '[seq: CIHQATGPQKPGSGF identifier:(Value_identifier:360)(Text_identifier:E)]\n[seq: CIHQGAGPTSKPG identifier:(Value_identifier:19)(Text_identifier:E)]\n[seq: CIHSQGAGPQTPG identifier:(Value_identifier:5)(Text_identifier:B)]\n', '[seq: CQSKPGAGGHPTQIF identifier:(Value_identifier:364)(Text_identifier:A)]\n[seq: CQKPPGTGGHQISAF identifier:(Value_identifier:392)(Text_identifier:B)]\n[seq: CHQKTGASGPPGQIF identifier:(Value_identifier:80)(Text_identifier:B)]\n[seq: CQGAPGQSHGPTKIF identifier:(Value_identifier:84)(Text_identifier:E)]\n', '[seq: CGQSPAGGKHQTPIF identifier:(Value_identifier:368)(Text_identifier:A)]\n[seq: PAGGKHQT identifier:(Value_identifier:42)(Text_identifier:B)]\n', '[seq: CTGPQQKHGAGSPIF identifier:(Value_identifier:372)(Text_identifier:C)]\n[seq: CTGIQKPHASGQPGF identifier:(Value_identifier:61)(Text_identifier:B)]\n', '[seq: CAQTSGKHGIQPPGF identifier:(Value_identifier:376)(Text_identifier:A)]\n[seq: CTQQSHKGAIGPPGF identifier:(Value_identifier:52)(Text_identifier:A)]\n', '[seq: CKSIPAPHGGGQTQF identifier:(Value_identifier:380)(Text_identifier:C)]\n[seq: KTAPIPHGGGQS identifier:(Value_identifier:38)(Text_identifier:D)]\n[seq: CGSIHAPQKGGPTQF identifier:(Value_identifier:48)(Text_identifier:E)]\n[seq: CQQTSIPHGGGKPAF identifier:(Value_identifier:90)(Text_identifier:D)]\n', '[seq: CKTIGPQGSGQAHPF identifier:(Value_identifier:384)(Text_identifier:A)]\n[seq: CSHTGPQGGKQAIPF identifier:(Value_identifier:49)(Text_identifier:B)]\n', '[seq: CQHQTAPKIPSGGGF identifier:(Value_identifier:388)(Text_identifier:B)]\n[seq: CQQKGIPHTPSGGAF identifier:(Value_identifier:46)(Text_identifier:A)]\n[seq: CQAQTKPSHPGGIGF identifier:(Value_identifier:87)(Text_identifier:B)]\n[seq: CTHAPIKQQPSGGGF identifier:(Value_identifier:24)(Text_identifier:C)]\n', '[seq: CQKPPGTGGHQISAF identifier:(Value_identifier:392)(Text_identifier:B)]\n[seq: CQTPPGKGQHAIGSF identifier:(Value_identifier:50)(Text_identifier:D)]\n[seq: CQPPQGGSGHKIATF identifier:(Value_identifier:60)(Text_identifier:E)]\n[seq: CQSKPGAGGHPTQIF identifier:(Value_identifier:364)(Text_identifier:A)]\n[seq: CKGIPSTGGHQPAQF identifier:(Value_identifier:48)(Text_identifier:A)]\n[seq: CAPKPGSGGTQIQHF identifier:(Value_identifier:99)(Text_identifier:D)]\n', '[seq: CQGAIHSKGQPTGPF identifier:(Value_identifier:396)(Text_identifier:E)]\n[seq: CKGTIHQQGPPAGSF identifier:(Value_identifier:91)(Text_identifier:D)]\n[seq: IHSKGQPQGGPF identifier:(Value_identifier:79)(Text_identifier:A)]\n[seq: ATHSKGQPIG identifier:(Value_identifier:37)(Text_identifier:B)]\n[seq: CQGAIQSPGTKGHPF identifier:(Value_identifier:55)(Text_identifier:D)]\n[seq: CKGA-QSIGQPTGP identifier:(Value_identifier:16)(Text_identifier:A)]\n[seq: CQHTAIKGGQPSGPF identifier:(Value_identifier:36)(Text_identifier:C)]\n', '[seq: CGGTPQSQHAIPKGF identifier:(Value_identifier:400)(Text_identifier:A)]\n[seq: CGGGPQSHQATPKIF identifier:(Value_identifier:63)(Text_identifier:C)]\n[seq: CSGQPQTGHPIAKGF identifier:(Value_identifier:51)(Text_identifier:E)]\n[seq: CGSGPQPTHAIKQGF identifier:(Value_identifier:23)(Text_identifier:C)]\n[seq: CGGSPAGHKTIPQQF identifier:(Value_identifier:44)(Text_identifier:B)]\n', '[seq: CGKHQAPPTQGSGIF identifier:(Value_identifier:400)(Text_identifier:A)]\n[seq: CGKHQAQPTQGSGIF identifier:(Value_identifier:10)(Text_identifier:E)]\n[seq: CHKTGGPPSQAQGIF identifier:(Value_identifier:152)(Text_identifier:A)]\n']

        self.DB_dataframe = pd.DataFrame()
        self.DB_dataframe['seq'] = self.seq
        self.DB_dataframe['info'] = self.info
        self.DB_dataframe['results'] = self.results

class HammingTrueFile:
    def __init__(self):
        self.seq = ['CPTGGAQGKHIPQSF', 'CKASIPQGTHGGQPF', 'CPIQGHPASQGGKTF', 'CATGIHGQSQPKPGF', 'CPKTGQQSAHGGPIF', 'CPQPGGKIAQGHSTF', 'CPGISPQGAKTQHGF', 'CQPQHPKTGGGIASF', 'CGKSQGPQGPAHITF', 'CTGGPSIHPQAKQGF', 'CITHGAGPPSQGKQF', 'CPHQQGGIASTKGPF', 'CIGSQPGPHKTQGAF', 'CGKSPHATPQIGGQF', 'CTQSKIGQAGHPGPF', 'CGPASTHIQQPGGKF', 'CGIKQTSGAHGPPQF', 'CITGSHGPQQGKAPF', 'CTGSPGPHAQKQIGF', 'CPQHGGISTPKQGAF', 'CGQPGTQIGSAKPHF', 'CQPQKGPASTIGHGF', 'CKQGPSGPTHAQGIF', 'CAPQQTPGSIKHGGF', 'CHPIQPKGTAGQGSF', 'CKIPGQPSQHGGATF', 'CAQGQPKPGHTGISF', 'CGGPTSQHKPAQGIF', 'CPAGPKQITQSGGHF', 'CGPPGQAHSGTQIKF', 'CGHGAGPIQQKTPSF', 'CIGPQAHQTGPKGSF', 'CQHGPIKSGTGPAQF', 'CKTGHSIGPQAPGQF', 'CQTQPGKGIHSGAPF', 'CSGQAPHPGKGQTIF', 'CHKTGGPPSQAQGIF', 'CQGSPIGQGATPKHF', 'CGGQKSQTIPGPAHF', 'CTQASHGPPQKGIGF', 'CKSTGAQHGPPIGQF', 'CSPQHAQGIGTPGKF', 'CPKISTHQQPGAGGF', 'CKHSGGPIAQQPGTF', 'CSAPPQGGGTIHQKF', 'CKTQSAIHGPQGPGF', 'CHGSQTPGGPIQKAF', 'CSGGQPGPAKTHIQF', 'CAKGQGPQPIHSGTF', 'CHGKGITPQAGSPQF', 'CGQPQPTAHGIGSKF', 'CPGKQTIAHQSGGPF', 'CQTQHGIPGSKPAGF', 'CQGIPPSGKAQHGTF', 'CHGQGKQTIAPPGSF', 'CAGHPGQSPIQTKGF', 'CQPGATSKGPGQHIF', 'CTHQGSAIKPPGGQF', 'CGIKTGPQQPAHSGF', 'CTHSPPGGGKAQQIF', 'CGSQPPITKAHGQGF', 'CPKGHQGGIQATSPF', 'CAGQITGHQKPPGSF', 'CSAPTIHQQGGPGKF', 'CPQQKGGGHTASIPF', 'CPQTSGAIHQKGPGF', 'CQQKPSAIGHGGPTF', 'CHQPAPIGTKQGSGF', 'CIKPHQASGGGTPQF', 'CQKPHQSGTIPGAGF', 'CIQKPSHTGPGQAGF', 'CGSAGQGPPHTQIKF', 'CTQGGSGQPHIKPAF', 'CAGHPPQGTKQGISF', 'CIPSAQPQGHKGGTF', 'CIPGQHAGPKGQTSF', 'CAQQSTKGPHGIGPF', 'CPPATGQHQSIGKGF', 'CGGHIPKSPAQQTGF', 'CIGPGKTPGHAQQSF', 'CSQKPGTIHQGAGPF', 'CAGPPKGQGQIHTSF', 'CKHIQGPGSQGPTAF', 'CSGQTGGPIKPHAQF', 'CTGQGHQPGPISKAF', 'CPGAKQIGTPSHQGF', 'CGSPQPIKTHGAGQF', 'CHQPGTPGKSGAQIF', 'CIHQATGPQKPGSGF', 'CQSKPGAGGHPTQIF', 'CGQSPAGGKHQTPIF', 'CTGPQQKHGAGSPIF', 'CAQTSGKHGIQPPGF', 'CKSIPAPHGGGQTQF', 'CKTIGPQGSGQAHPF', 'CQHQTAPKIPSGGGF', 'CQKPPGTGGHQISAF', 'CQGAIHSKGQPTGPF', 'CGGTPQSQHAIPKGF', 'CGKHQAPPTQGSGIF']
        self.info = [62, 6, 83, 22, 73, 43, 7, 92, 9, 77, 30, 68, 29, 52, 69, 43, 25, 11, 14, 42, 46, 69, 48, 19, 91, 55, 51, 34, 85, 34, 64, 84, 66, 73, 76, 72, 10, 20, 60, 67, 71, 30, 11, 46, 73, 23, 6, 45, 58, 12, 35, 48, 60, 38, 42, 35, 3, 77, 19, 3, 20, 48, 63, 1, 95, 58, 7, 53, 74, 84, 75, 46, 55, 86, 66, 24, 28, 24, 49, 56, 31, 95, 49, 58, 53, 61, 59, 98, 47, 20, 17, 28, 5, 6, 92, 38, 50, 50, 43, 6]
        self.results = ['[seq: CPTGGAQGKHIPQSF (Value_identifier: 8) (Text_identifier: A)]\n[seq: CPTAGAQGKHIPQSF (Value_identifier: 8) (Text_identifier: A)]\n', '[seq: CKASIPQGTHGGQPF (Value_identifier: 10) (Text_identifier: C)]\n[seq: CKASIPQGTHGGQPF (Value_identifier: 12) (Text_identifier: C)]\n', '[seq: CPIQGHPASQGGKTF (Value_identifier: 16) (Text_identifier: A)]\n[seq: CPIQGHPASQGGKTF (Value_identifier: 12) (Text_identifier: A)]\n', '[seq: CATGIHGQSQPKPGF (Value_identifier: 20) (Text_identifier: C)]\n[seq: CATGIHGQSQPKPGF (Value_identifier: 14) (Text_identifier: A)]\n', '[seq: CPKTGQQSAHGGPIF (Value_identifier: 16) (Text_identifier: A)]\n[seq: CPKTGQQSAHGGPIF (Value_identifier: 24) (Text_identifier: A)]\n', '[seq: CPQPGGKIAQGHSTF (Value_identifier: 18) (Text_identifier: C)]\n[seq: CPQPGGKIAQGHSTF (Value_identifier: 28) (Text_identifier: B)]\n', '[seq: CPGISPQGAKTQHGF (Value_identifier: 20) (Text_identifier: A)]\n[seq: CPGISPQGAKTQHGF (Value_identifier: 32) (Text_identifier: B)]\n', '[seq: CQPQHPKTGGGIASF (Value_identifier: 36) (Text_identifier: E)]\n[seq: CQPQHPKTGGGIASF (Value_identifier: 22) (Text_identifier: A)]\n', '[seq: CGKSQGPQGPAHITF (Value_identifier: 40) (Text_identifier: A)]\n[seq: CGKSQGPQGPAHITF (Value_identifier: 24) (Text_identifier: A)]\n', '[seq: CTGGPSIHPQAKQGF (Value_identifier: 44) (Text_identifier: A)]\n', '[seq: CITHGAGPPSQGKQF (Value_identifier: 48) (Text_identifier: C)]\n', '[seq: CPHQQGGIASTKGPF (Value_identifier: 52) (Text_identifier: A)]\n', '[seq: CIGSQPGPHKTQGAF (Value_identifier: 56) (Text_identifier: C)]\n', '[seq: CGKSPHATPQIGGQF (Value_identifier: 60) (Text_identifier: A)]\n', '[seq: CTQSKIGQAGHPGPF (Value_identifier: 64) (Text_identifier: B)]\n', '[seq: CGPASTHIQQPGGKF (Value_identifier: 68) (Text_identifier: B)]\n', '[seq: CGIKQTSGAHGPPQF (Value_identifier: 72) (Text_identifier: E)]\n[seq: CGIKQTSGAHGPPQF (Value_identifier: 26) (Text_identifier: C)]\n', '[seq: CITGSHGPQQGKAPF (Value_identifier: 76) (Text_identifier: A)]\n[seq: CITGSHGPQQGKAPF (Value_identifier: 28) (Text_identifier: A)]\n', '[seq: CTGSPGPHAQKQIGF (Value_identifier: 30) (Text_identifier: A)]\n[seq: CTGSPGPHAQKQIGF (Value_identifier: 80) (Text_identifier: A)]\n', '[seq: CPQHGGISTPKQGAF (Value_identifier: 32) (Text_identifier: A)]\n[seq: CPQHGGISTPKQGAF (Value_identifier: 84) (Text_identifier: C)]\n', '[seq: CGQPGTQIGSAKPHF (Value_identifier: 34) (Text_identifier: C)]\n[seq: CGQPGTQIGSAKPHF (Value_identifier: 88) (Text_identifier: A)]\n', '[seq: CQPQKGPASTIGHGF (Value_identifier: 92) (Text_identifier: C)]\n[seq: CQPQKGPASTIGHGF (Value_identifier: 36) (Text_identifier: A)]\n', '[seq: CKQGPSGPTKAQGIF (Value_identifier: 16) (Text_identifier: C)]\n[seq: CKQGPSGPTHAQGIF (Value_identifier: 96) (Text_identifier: A)]\n[seq: CKQGPSGPTHAQGIF (Value_identifier: 38) (Text_identifier: A)]\n', '[seq: CAPQQTPGSIKHGGF (Value_identifier: 40) (Text_identifier: A)]\n[seq: CAPQQTPGSIKHGGF (Value_identifier: 100) (Text_identifier: B)]\n', '[seq: CHPIQPKGTAGQGSF (Value_identifier: 104) (Text_identifier: B)]\n[seq: CHPIQPKGTAGQGSF (Value_identifier: 41) (Text_identifier: E)]\n', '[seq: CKIPGQPSQHGGATF (Value_identifier: 108) (Text_identifier: E)]\n', '[seq: CAQGQPKPGHTGISF (Value_identifier: 112) (Text_identifier: A)]\n', '[seq: CGGPTSQHKPAQGIF (Value_identifier: 116) (Text_identifier: A)]\n', '[seq: CPAGPKQITQSGGHF (Value_identifier: 120) (Text_identifier: C)]\n', '[seq: CGPPGQAHSGTQIKF (Value_identifier: 124) (Text_identifier: A)]\n', '[seq: CGHGAGPIQQKTPSF (Value_identifier: 128) (Text_identifier: C)]\n', '[seq: CIGPQAHQTGPKGSF (Value_identifier: 132) (Text_identifier: A)]\n', '[seq: CQHGPIKSGTGPAQF (Value_identifier: 136) (Text_identifier: B)]\n', '[seq: CKTGHSIGPQAPGQF (Value_identifier: 140) (Text_identifier: B)]\n', '[seq: CQTQPGKGIHSGAPF (Value_identifier: 144) (Text_identifier: E)]\n', '[seq: CSGQAPHPGKGQTIF (Value_identifier: 148) (Text_identifier: A)]\n', '[seq: CHKTGGPPSQAQGIF (Value_identifier: 152) (Text_identifier: A)]\n', '[seq: CQGSPIGQGATPKHF (Value_identifier: 156) (Text_identifier: C)]\n', '[seq: CGGQKSQTIPGPAHF (Value_identifier: 160) (Text_identifier: A)]\n', '[seq: CTQASHGPPQKGIGF (Value_identifier: 164) (Text_identifier: C)]\n', '[seq: CKSTGAQHGPPIGQF (Value_identifier: 168) (Text_identifier: A)]\n', '[seq: CSPQHAQGIGTPGKF (Value_identifier: 172) (Text_identifier: B)]\n', '[seq: CPKISTHQQPGAGGF (Value_identifier: 176) (Text_identifier: B)]\n', '[seq: CKHSGGPIAQQPGTF (Value_identifier: 180) (Text_identifier: E)]\n', '[seq: CSAPPQGGGTIHQKF (Value_identifier: 184) (Text_identifier: A)]\n', '[seq: CKTQSAIHGPQGPGF (Value_identifier: 188) (Text_identifier: A)]\n', '[seq: CHGSQTPGGPIQKAF (Value_identifier: 192) (Text_identifier: C)]\n', '[seq: CSGGQPGPAKTHIQF (Value_identifier: 196) (Text_identifier: A)]\n', '[seq: CAKGQGPQPIHSGTF (Value_identifier: 200) (Text_identifier: C)]\n', '[seq: CHGKGITPQAGSPQF (Value_identifier: 204) (Text_identifier: A)]\n', '[seq: CGQPQPTAHGIGSKF (Value_identifier: 208) (Text_identifier: B)]\n', '[seq: CPGKQTIAHQSGGPF (Value_identifier: 212) (Text_identifier: B)]\n', '[seq: CQTQHGIPGSKPAGF (Value_identifier: 216) (Text_identifier: E)]\n', '[seq: CQGIPPSGKAQHGTF (Value_identifier: 220) (Text_identifier: A)]\n', '[seq: CHGQGKQTIAPPGSF (Value_identifier: 224) (Text_identifier: A)]\n', '[seq: CAGHPGQSPIQTKGF (Value_identifier: 228) (Text_identifier: C)]\n', '[seq: CQPGATSKGPGQHIF (Value_identifier: 232) (Text_identifier: A)]\n', '[seq: CTHQGSAIKPPGGQF (Value_identifier: 236) (Text_identifier: C)]\n', '[seq: CGIKTGPQQPAHSGF (Value_identifier: 240) (Text_identifier: A)]\n', '[seq: CTHSPPGGGKAQQIF (Value_identifier: 244) (Text_identifier: B)]\n', '[seq: CGSQPPITKAHPQGF (Value_identifier: 8) (Text_identifier: D)]\n[seq: CGSQPPITKAHGQGF (Value_identifier: 248) (Text_identifier: B)]\n', '[seq: CPKGHQGGIQATSPF (Value_identifier: 252) (Text_identifier: E)]\n', '[seq: CAGQITGHQKPPGSF (Value_identifier: 256) (Text_identifier: A)]\n', '[seq: CSAPTIHQQGGPGKF (Value_identifier: 260) (Text_identifier: A)]\n', '[seq: CPQQKGGGHTASIPF (Value_identifier: 264) (Text_identifier: C)]\n', '[seq: CPQTSGAIHQKGPGF (Value_identifier: 268) (Text_identifier: A)]\n', '[seq: CQQKPSAIGHGGPTF (Value_identifier: 272) (Text_identifier: C)]\n', '[seq: CHQPAPIGTKQGSGF (Value_identifier: 276) (Text_identifier: A)]\n', '[seq: CIKPHQASGGGTPQF (Value_identifier: 280) (Text_identifier: B)]\n', '[seq: CQKPHQSGTIPGAGF (Value_identifier: 284) (Text_identifier: B)]\n', '[seq: CIQKPSHTGPGQAGF (Value_identifier: 288) (Text_identifier: E)]\n', '[seq: CGSAGQGPPHTQIKF (Value_identifier: 292) (Text_identifier: A)]\n', '[seq: CTQGGSGQPHIKPAF (Value_identifier: 296) (Text_identifier: A)]\n', '[seq: CAGHPPQGTKQGISF (Value_identifier: 300) (Text_identifier: C)]\n', '[seq: CIPSAQPQGHKGGTF (Value_identifier: 304) (Text_identifier: A)]\n', '[seq: CIPGQHAGPKGQTSF (Value_identifier: 308) (Text_identifier: C)]\n', '[seq: CAQQSTKGPHGIGPF (Value_identifier: 312) (Text_identifier: A)]\n', '[seq: CPPATGQHQSIGKGF (Value_identifier: 316) (Text_identifier: B)]\n', '[seq: CGGHIPKSPAQQTGF (Value_identifier: 320) (Text_identifier: B)]\n', '[seq: CIGPGKTPGHAQQSF (Value_identifier: 324) (Text_identifier: E)]\n', '[seq: CSQKPGTIHQGAGPF (Value_identifier: 328) (Text_identifier: A)]\n', '[seq: CAGPPKGQGQIHTSF (Value_identifier: 332) (Text_identifier: A)]\n', '[seq: CKHIQGPGSQGPTAF (Value_identifier: 336) (Text_identifier: C)]\n', '[seq: CSGQTGGPIKPHAQF (Value_identifier: 340) (Text_identifier: A)]\n', '[seq: CTGQGHQPGPISKAF (Value_identifier: 344) (Text_identifier: C)]\n', '[seq: CPGAKQIGTPSHQGF (Value_identifier: 348) (Text_identifier: A)]\n', '[seq: CGSPQPIKTHGAGQF (Value_identifier: 352) (Text_identifier: B)]\n', '[seq: CHQPGTPGKSGAQIF (Value_identifier: 356) (Text_identifier: B)]\n', '[seq: CIHQATGPQKPGSGF (Value_identifier: 360) (Text_identifier: E)]\n', '[seq: CQSKPGAGGHPTQIF (Value_identifier: 364) (Text_identifier: A)]\n', '[seq: CGQSPAGGKHQTPIF (Value_identifier: 368) (Text_identifier: A)]\n', '[seq: CTGPQQKHGAGSPIF (Value_identifier: 372) (Text_identifier: C)]\n', '[seq: CAQTSGKHGIQPPGF (Value_identifier: 376) (Text_identifier: A)]\n', '[seq: CKSIPAPHGGGQTQF (Value_identifier: 380) (Text_identifier: C)]\n', '[seq: CKTIGPQGSGQAHPF (Value_identifier: 384) (Text_identifier: A)]\n', '[seq: CQHQTAPKIPSGGGF (Value_identifier: 388) (Text_identifier: B)]\n', '[seq: CQKPPGTGGHQISAF (Value_identifier: 392) (Text_identifier: B)]\n', '[seq: CQGAIHSKGQPTGPF (Value_identifier: 396) (Text_identifier: E)]\n', '[seq: CGGTPQSQHAIPKGF (Value_identifier: 400) (Text_identifier: A)]\n', '[seq: CGKHQAPPTQGSGIF (Value_identifier: 400) (Text_identifier: A)]\n[seq: CGKHQAQPTQGSGIF (Value_identifier: 10) (Text_identifier: E)]\n']


        self.DB_dataframe = pd.DataFrame()
        self.DB_dataframe['seq'] = self.seq
        self.DB_dataframe['info'] = self.info
        self.DB_dataframe['results'] = self.results

class TestDatabaseComparator:
    """
    The TestDatabaseComparator class is responsible for testing the functionality of the DB_comparator class.
    
    It includes methods to test initialization, exporting data frames, and comparing databases using various methods.
    """
    
    def __init__(self):
        self.test_database = DatabaseData().DB_dataframe
        self.exact_match_true_file = ExactMatchTrueFile().DB_dataframe
        self.aligner_true_file = AlignerTrueFile().DB_dataframe
        self.blast_true_file = BlastTrueFile().DB_dataframe
        self.hamming_true_file = HammingTrueFile().DB_dataframe
        self.query_file = QueryFile().DB_dataframe
        self.exit_code = 0

    def start(self):

        os.makedirs("TMP_testing_folder", exist_ok=True)
        os.makedirs("TMP_testing_folder/Databases", exist_ok=True)
        os.makedirs("TMP_testing_folder/True_files", exist_ok=True)

        self.test_database.to_csv("TMP_testing_folder/Databases/test_database.csv", index=False)
        self.query_file.to_excel("TMP_testing_folder/test_query.xlsx", index=False)
        self.exact_match_true_file.to_excel("TMP_testing_folder/True_files/exact_match_TEST_true.xlsx", index=False)
        self.aligner_true_file.to_excel("TMP_testing_folder/True_files/aligner_TEST_true.xlsx", index=False)
        self.blast_true_file.to_excel("TMP_testing_folder/True_files/blast_TEST_true.xlsx", index=False)
        self.hamming_true_file.to_excel("TMP_testing_folder/True_files/hamming_distances_TEST_true.xlsx", index=False)


        self.__generate_config_file()
        self.__generate_python_script()

        exit_code = 0
        try:
            result = subprocess.run(
                ["python", "run_independent.py"],
                capture_output=True,
                text=True,
                encoding="utf-8",
                check=True
            )
            # Zobrazit výstup ze stdout i stderr přesně jako v terminálu
            print(result.stdout)
        except subprocess.CalledProcessError as e:
            print(e.stdout)
            print(e.stderr)
            exit_code = e.returncode

        self.__clean_up()
        self.exit_code = exit_code
    
    def __generate_config_file(self):
        path = "TMP_testing_folder/test_config_file.txt"

        file = open(path, "w")
        # Database
        file.write("QUERY TMP_testing_folder/test_query.xlsx seq\n")
        file.write("DB TMP_testing_folder/Databases/test_database.csv sequence [Value_identifier, Text_identifier]\n")

        file.write("number_of_processors 3\n")

        file.write("SWA_tolerance 0.9\n")
        file.write("SWA_matrix BLOSUM62\n")
        file.write("SWA_mode global\n")

        file.write("HD_max_distance 1\n")

        file.write("BLAST_e_value 0.05\n")
        file.write("BLAST_database_name clip_seq_db\n")
        file.write("BLAST_output_name blastp_output.txt\n")

        file.close()

    def __generate_python_script(self):
        path = "run_independent.py"
        with open(path, "w", encoding="utf-8") as file:
            file.write("import sys\n")
            file.write("try:\n")
            file.write("    from Database_comparator import run_independent_test\n")
            file.write("except ImportError:\n")
            file.write("    import os\n")
            file.write("    project_root = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))\n")
            file.write("    sys.path.append(project_root)\n")
            file.write("    from Database_comparator import run_independent_test\n")
            file.write("\n")
            file.write("exit_code, table = run_independent_test.main()\n")
            file.write("try:\n")
            file.write("    print(table)\n")
            file.write("except UnicodeEncodeError:\n")
            file.write("    sys.stdout.buffer.write((str(table) + '\\n').encode('utf-8'))\n")
            file.write("    sys.stdout.buffer.flush()\n")
            file.write("sys.exit(exit_code)\n")



    def __clean_up(self):
        """
        Cleans up the temporary testing folder and files created during the test.
        """
        if os.path.exists("TMP_testing_folder"): shutil.rmtree("TMP_testing_folder")
        if os.path.exists("run_independent.py"): os.remove("run_independent.py")
        


if __name__ == "__main__":
    test = TestDatabaseComparator()
    test.start()
    sys.exit(test.exit_code)
    
    